@@ -1,6 +1,6 @@
 /*
     Text maid
-    copyright (c) 1998-2002 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2003 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -39,13 +39,14 @@ GtkWidget *abort_dialog(const gchar *label)
 	GtkWidget *dialog,*button;
 
 	/* ᥤ󥦥ɥ */
-	dialog=gtk_window_new(GTK_WINDOW_DIALOG);
+	dialog = gtk_window_new (GTK_WINDOW_TOPLEVEL);
 	gtk_window_set_title(GTK_WINDOW(dialog),_("Abort"));
-	gtk_signal_connect(GTK_OBJECT(dialog),"delete-event",
-											GTK_SIGNAL_FUNC(gtk_true),NULL);
+	g_signal_connect (G_OBJECT (dialog), "delete-event",
+												G_CALLBACK (gtk_true), NULL);
 	/* ܥ */
 	button=gtk_button_new_with_label(label);
-	gtk_signal_connect(GTK_OBJECT(button),"clicked",abort_dialog_clicked,NULL);
+	g_signal_connect (G_OBJECT (button), "clicked",
+									G_CALLBACK (abort_dialog_clicked), NULL);
 	GTK_WIDGET_SET_FLAGS(button,GTK_CAN_DEFAULT);
 
 	/* ե졼ȥܥå */
