@@ -17,19 +17,19 @@
     Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
 #include "abort.h"
+#include "charlist.h"
 #include "command.h"
 #include "edit.h"
 #include "file.h"
 #include "find.h"
 #include "general.h"
 #include "jump.h"
-#ifdef USE_GDKPIXBUF
-# include "print.h"
-#endif
+#include "print.h"
 #include "prop.h"
+#include "reload.h"
 #include "replace.h"
 #include "repinfo.h"
-#include "signal.h"
+#include "sigfile.h"
 #include "valchr.h"
 #include "misc/misc.h"
 
@@ -50,7 +50,7 @@ static void command_open_ok(GtkWidget *widget,GtkWidget *dialog)
 {
 	gchar **file;
 
-	file=gtk_object_get_user_data(GTK_OBJECT(dialog));
+	file = g_object_get_data (G_OBJECT (dialog), "user_data");
 	*file
 		=g_strdup(gtk_file_selection_get_filename(GTK_FILE_SELECTION(dialog)));
     gtk_widget_destroy(dialog);
@@ -64,13 +64,14 @@ void command_open(gpointer callback_data,guint callback_action,
 	GtkWidget *dialog;
 
 	dialog=gtk_file_selection_new(_("Open"));
-	gtk_signal_connect(GTK_OBJECT(dialog),"destroy",gtk_main_quit,NULL);
-	gtk_signal_connect(GTK_OBJECT(GTK_FILE_SELECTION(dialog)->ok_button),
-										"clicked",command_open_ok,dialog);
-	gtk_signal_connect_object(
-						GTK_OBJECT(GTK_FILE_SELECTION(dialog)->cancel_button),
-							"clicked",gtk_widget_destroy,GTK_OBJECT(dialog));
-	gtk_object_set_user_data(GTK_OBJECT(dialog),&file);
+	g_signal_connect (G_OBJECT (dialog), "destroy",
+											G_CALLBACK (gtk_main_quit), NULL);
+	g_signal_connect (G_OBJECT (GTK_FILE_SELECTION (dialog)->ok_button),
+							"clicked", G_CALLBACK (command_open_ok), dialog);
+	g_signal_connect_swapped (
+						G_OBJECT (GTK_FILE_SELECTION (dialog)->cancel_button),
+			"clicked", G_CALLBACK (gtk_widget_destroy), GTK_OBJECT (dialog));
+	g_object_set_data (G_OBJECT (dialog), "user_data", &file);
 	if (open_path!=NULL)
 		gtk_file_selection_set_filename(GTK_FILE_SELECTION(dialog),open_path);
 	gtk_widget_show(dialog);
@@ -79,7 +80,7 @@ void command_open(gpointer callback_data,guint callback_action,
 	if (file!=NULL) {
 		g_free(open_path);
 		open_path=misc_get_full_path(file);
-		*g_basename(open_path)='\0';
+		*(gchar *)g_basename(open_path)='\0';
 		file_open_edit(file);
 		g_free(file);
 	}
@@ -92,9 +93,10 @@ void command_save(gpointer callback_data,guint callback_action,
 	gchar *text;
 	TmaidWindow *tmaid;
 
-	tmaid=gtk_object_get_user_data(GTK_OBJECT(
-				gtk_notebook_get_nth_page(GTK_NOTEBOOK(notebook),
-					gtk_notebook_get_current_page(GTK_NOTEBOOK(notebook)))));
+	tmaid = g_object_get_data (G_OBJECT
+				(gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook),
+					gtk_notebook_get_current_page (GTK_NOTEBOOK (notebook)))),
+																"user_data");
 	if (tmaid->create) {
 		command_saveas(callback_data,callback_action,widget);
 	} else {
@@ -120,15 +122,16 @@ void command_saveas(gpointer callback_data,guint callback_action,
 
 	child=gtk_notebook_get_nth_page(GTK_NOTEBOOK(notebook),
 						gtk_notebook_get_current_page(GTK_NOTEBOOK(notebook)));
-	tmaid=gtk_object_get_user_data(GTK_OBJECT(child));
+	tmaid = g_object_get_data (G_OBJECT (child), "user_data");
 	dialog=gtk_file_selection_new(_("Save As"));
-	gtk_signal_connect(GTK_OBJECT(dialog),"destroy",gtk_main_quit,NULL);
-	gtk_signal_connect(GTK_OBJECT(GTK_FILE_SELECTION(dialog)->ok_button),
-										"clicked",command_open_ok,dialog);
-	gtk_signal_connect_object(
-						GTK_OBJECT(GTK_FILE_SELECTION(dialog)->cancel_button),
-							"clicked",gtk_widget_destroy,GTK_OBJECT(dialog));
-	gtk_object_set_user_data(GTK_OBJECT(dialog),&file);
+	g_signal_connect (G_OBJECT (dialog), "destroy",
+											G_CALLBACK (gtk_main_quit), NULL);
+	g_signal_connect (G_OBJECT (GTK_FILE_SELECTION (dialog)->ok_button),
+							"clicked", G_CALLBACK (command_open_ok), dialog);
+	g_signal_connect_swapped (
+						G_OBJECT (GTK_FILE_SELECTION (dialog)->cancel_button),
+			"clicked", G_CALLBACK (gtk_widget_destroy), GTK_OBJECT (dialog));
+	g_object_set_data (G_OBJECT (dialog), "user_data", &file);
 	if (save_path!=NULL)
 		gtk_file_selection_set_filename(GTK_FILE_SELECTION(dialog),save_path);
 	gtk_widget_show(dialog);
@@ -142,7 +145,7 @@ void command_saveas(gpointer callback_data,guint callback_action,
 											&& file_save_text(file,tmaid)) {
 			g_free(save_path);
 			save_path=misc_get_full_path(file);
-			*g_basename(save_path)='\0';
+			*(gchar *)g_basename(save_path)='\0';
 			/* ե̾Ĵ٤ */
 			file_delete_edit(tmaid->file);
 			tmaid->file[0]='\0';
@@ -171,20 +174,20 @@ void command_reload(gpointer callback_data,guint callback_action,
 															GtkWidget *widget)
 {
 	gchar *text;
-	gint result=0;
+	gint i;
+	GList *glist;
 	LineBuffer *p;
-	TmaidWindow *tmaid;
+	TmaidWindow *tmaid, *tmaid_dst;
 
-	tmaid=gtk_object_get_user_data(GTK_OBJECT(
-				gtk_notebook_get_nth_page(GTK_NOTEBOOK(notebook),
-					gtk_notebook_get_current_page(GTK_NOTEBOOK(notebook)))));
-	if (tmaid->edit) {
-		text=g_strdup_printf(
-			_("File %s was edited.\nRestore to existed file?"),tmaid->file);
-		result=misc_message_box("Text maid",text,1,_("_Yes"),_("_No"),NULL);
-		g_free(text);
-	}
-	if (result==0) {
+	tmaid = g_object_get_data (G_OBJECT
+				(gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook),
+					gtk_notebook_get_current_page (GTK_NOTEBOOK (notebook)))),
+																"user_data");
+	text = tmaid->edit ? g_strdup_printf
+						(_("File %s was edited.\nRestore to existed file?"),
+														tmaid->file) : NULL;
+	if (reload_dialog (&tmaid->ft, text))
+	  {
 		/* Хåե */
 		while (tmaid->start->prev!=NULL)
 			tmaid->start=tmaid->start->prev;
@@ -201,41 +204,62 @@ void command_reload(gpointer callback_data,guint callback_action,
 		tmaid->select.x = -1;
 		/* ɤ߹ */
 		file_open_text(tmaid);
-		if (tmaid->start==NULL) {
-			/* ե뤬0ХȤΤȤ */
-			tmaid->off=0;
-			tmaid->max=1;
-			tmaid->start=g_malloc(sizeof(LineBuffer));
-			tmaid->start->length=0;
-			tmaid->start->margin=FALSE;
-			tmaid->start->text=NULL;
-			tmaid->start->prev=tmaid->start->next=NULL;
-		}
+		/* ޡ */
+		if (tmaid->ft.limit)
+			modify_margin (tmaid);
 		tmaid_change_edit (tmaid, FALSE);
-		misc_set_scroll_bar(tmaid->hscroll,signal_value_changed_hscroll,tmaid,
-					0,edit_get_width_max(tmaid)+1,
-					MAX(tmaid->drawing->allocation.width/tmaid->font_width,1),
+		misc_set_scroll_bar (tmaid->hscroll,
+				G_CALLBACK (signal_value_changed_hscroll), tmaid,
+				0, edit_get_width_max (tmaid) + 1,
+				MAX (tmaid->drawing->allocation.width / tmaid->font_width, 1),
 																tmaid->top.x);
-		misc_set_scroll_bar(tmaid->vscroll,signal_value_changed_vscroll,tmaid,
-				0,tmaid->max,
-				MAX(tmaid->drawing->allocation.height/(tmaid->font_height),1),
+		misc_set_scroll_bar (tmaid->vscroll,
+			G_CALLBACK (signal_value_changed_vscroll), tmaid,
+			0, tmaid->max,
+			MAX (tmaid->drawing->allocation.height / tmaid->font_height, 1),
 																tmaid->top.y);
 		set_menu_bar(tmaid);
 		draw_caret(tmaid,NULL);
 		gtk_widget_draw(tmaid->drawing,NULL);
-	}
+		if (tmaid->ft.ft_id >= 0)
+		  {
+			/* Ʊե륿פ򤹤٤ѹ */
+			for (i = 0; i < ftnum; i++)
+				if (ftype[i].ft_id == tmaid->ft.ft_id)
+				  {
+					property_copy (ftype + i, &tmaid->ft);
+					break;
+				  }
+			glist = gtk_container_children (GTK_CONTAINER (notebook));
+			for (i = g_list_length (glist) - 1; i >= 0; i--)
+			  {
+				tmaid_dst = g_object_get_data
+						(G_OBJECT (g_list_nth_data (glist, i)), "user_data");
+				if (tmaid->ft.ft_id == tmaid_dst->ft.ft_id
+														&& tmaid != tmaid_dst)
+				  {
+					property_copy (&tmaid_dst->ft, &tmaid->ft);
+					g_free (tmaid_dst->ft.charset);
+					tmaid_dst->ft.charset = g_strdup (tmaid->ft.charset);
+				  }
+			  }
+			g_list_free (glist);
+		  }
+		charlist_renewal_all (tmaid->ft.charset, tmaid->ft.ft_id);
+	  }
+	g_free(text);
 }
 
 
-#ifdef USE_GDKPIXBUF
 void command_print(gpointer callback_data,guint callback_action,
 															GtkWidget *widget)
 {
 	TmaidWindow *tmaid;
 
-	tmaid=gtk_object_get_user_data(GTK_OBJECT(
-				gtk_notebook_get_nth_page(GTK_NOTEBOOK(notebook),
-					gtk_notebook_get_current_page(GTK_NOTEBOOK(notebook)))));
+	tmaid = g_object_get_data (G_OBJECT
+				(gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook),
+					gtk_notebook_get_current_page (GTK_NOTEBOOK (notebook)))),
+																"user_data");
 	printer.select=tmaid->select.x>=0;
 	printer.column=tmaid->ft.margin;
 	printer.font_width=tmaid->font_width;
@@ -243,44 +267,53 @@ void command_print(gpointer callback_data,guint callback_action,
 	if (print_dialog(&printer))
 		print_out(tmaid,&printer);
 }
-#endif
 
 
 void command_property(gpointer callback_data,guint callback_action,
 															GtkWidget *widget)
 {
 	gint i;
-	GList *glist;
 	FileType ft;
+	GList *glist;
 	TmaidWindow *tmaid;
 
-	tmaid=gtk_object_get_user_data(GTK_OBJECT(
-				gtk_notebook_get_nth_page(GTK_NOTEBOOK(notebook),
-					gtk_notebook_get_current_page(GTK_NOTEBOOK(notebook)))));
-	ft.text=ft.ext=NULL;
+	tmaid = g_object_get_data (G_OBJECT
+				(gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook),
+					gtk_notebook_get_current_page (GTK_NOTEBOOK (notebook)))),
+																"user_data");
+	g_memset (&ft, 0, sizeof (FileType));
 	property_copy (&ft, &tmaid->ft);
+	ft.charset = g_strdup (tmaid->ft.charset);
 	if (property_dialog(&ft)) {
 		if (ft.ft_id<0) {
 			/* ̵°ΤȤˤϤΥɥѹ */
-			property_change(tmaid,&ft);
+			g_free (tmaid->ft.charset);
+			tmaid->ft.charset = g_strdup (ft.charset);
+			property_change (tmaid,&ft);
 		} else {
 			/* Ʊե륿פ򤹤٤ѹ */
 			tmaid->ft.ft_id=ft.ft_id;
 			for (i=0;i<ftnum;i++)
 				if (ftype[i].ft_id==ft.ft_id) {
-					property_copy (ftype+i, &ft);
+					property_copy (ftype + i, &ft);
 					break;
 				}
 			glist=gtk_container_children(GTK_CONTAINER(notebook));
 			for (i=g_list_length(glist)-1;i>=0;i--) {
-				tmaid=gtk_object_get_user_data(
-										GTK_OBJECT(g_list_nth_data(glist,i)));
-				if (tmaid->ft.ft_id==ft.ft_id)
-					property_change(tmaid,&ft);
+				tmaid = g_object_get_data
+						(G_OBJECT (g_list_nth_data (glist, i)), "user_data");
+				if (tmaid->ft.ft_id == ft.ft_id)
+				  {
+					g_free (tmaid->ft.charset);
+					tmaid->ft.charset = g_strdup (ft.charset);
+					property_change (tmaid, &ft);
+				  }
 			}
 			g_list_free(glist);
 		}
+		charlist_renewal_all (ft.charset, ft.ft_id);
 	}
+	g_free (ft.charset);
 	g_free(ft.font_name);
 }
 
@@ -292,8 +325,8 @@ void command_close(gpointer callback_data,guint callback_action,
 	TmaidWindow *tmaid;
 
 	if ((page=gtk_notebook_get_current_page(GTK_NOTEBOOK(notebook)))>=0) {
-		tmaid=gtk_object_get_user_data(GTK_OBJECT(
-					gtk_notebook_get_nth_page(GTK_NOTEBOOK(notebook),page)));
+		tmaid = g_object_get_data (G_OBJECT (gtk_notebook_get_nth_page
+								(GTK_NOTEBOOK (notebook), page)), "user_data");
 		if (prompt_close(tmaid))
 			gtk_notebook_remove_page(GTK_NOTEBOOK(notebook),page);
 	}
@@ -317,9 +350,10 @@ void command_undo(gpointer callback_data,guint callback_action,
 {
 	TmaidWindow *tmaid;
 
-	tmaid=gtk_object_get_user_data(GTK_OBJECT(
-				gtk_notebook_get_nth_page(GTK_NOTEBOOK(notebook),
-					gtk_notebook_get_current_page(GTK_NOTEBOOK(notebook)))));
+	tmaid = g_object_get_data (G_OBJECT
+				(gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook),
+					gtk_notebook_get_current_page (GTK_NOTEBOOK (notebook)))),
+																"user_data");
 	history_operation(tmaid,FALSE);
 }
 
@@ -329,9 +363,10 @@ void command_redo(gpointer callback_data,guint callback_action,
 {
 	TmaidWindow *tmaid;
 
-	tmaid=gtk_object_get_user_data(GTK_OBJECT(
-				gtk_notebook_get_nth_page(GTK_NOTEBOOK(notebook),
-					gtk_notebook_get_current_page(GTK_NOTEBOOK(notebook)))));
+	tmaid = g_object_get_data (G_OBJECT
+				(gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook),
+					gtk_notebook_get_current_page (GTK_NOTEBOOK (notebook)))),
+																"user_data");
 	history_operation(tmaid,TRUE);
 }
 
@@ -351,9 +386,10 @@ void command_copy(gpointer callback_data,guint callback_action,
 	TmaidWindow *tmaid;
 
 	if (gtk_selection_owner_set(window,atom_clipboard,GDK_CURRENT_TIME)) {
-		tmaid=gtk_object_get_user_data(GTK_OBJECT(
-				gtk_notebook_get_nth_page(GTK_NOTEBOOK(notebook),
-					gtk_notebook_get_current_page(GTK_NOTEBOOK(notebook)))));
+		tmaid = g_object_get_data (G_OBJECT
+				(gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook),
+					gtk_notebook_get_current_page (GTK_NOTEBOOK (notebook)))),
+																"user_data");
 		g_free(clipboard_text);
 		length=edit_get_sel_bytes(tmaid,&tmaid->select,&tmaid->cursor);
 		clipboard_text=g_malloc((length+1)*sizeof(gchar));
@@ -376,9 +412,10 @@ void command_delete(gpointer callback_data,guint callback_action,
 	TmaidHistory *d;
 	TmaidWindow *tmaid;
 
-	tmaid=gtk_object_get_user_data(GTK_OBJECT(
-				gtk_notebook_get_nth_page(GTK_NOTEBOOK(notebook),
-					gtk_notebook_get_current_page(GTK_NOTEBOOK(notebook)))));
+	tmaid = g_object_get_data (G_OBJECT
+				(gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook),
+					gtk_notebook_get_current_page (GTK_NOTEBOOK (notebook)))),
+																"user_data");
 	d=edit_operation(tmaid,NULL,0,TRUE,FALSE);
 	d->next=tmaid->undo;
 	tmaid->undo=d;
@@ -394,9 +431,10 @@ void command_margin(gpointer callback_data,guint callback_action,
 
 	if (misc_message_box("Text maid",_("Return at Right Margin?"),1,
 												_("_Yes"),_("_No"),NULL)==0) {
-		tmaid=gtk_object_get_user_data(GTK_OBJECT(
-				gtk_notebook_get_nth_page(GTK_NOTEBOOK(notebook),
-					gtk_notebook_get_current_page(GTK_NOTEBOOK(notebook)))));
+		tmaid = g_object_get_data (G_OBJECT
+				(gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook),
+					gtk_notebook_get_current_page (GTK_NOTEBOOK (notebook)))),
+																"user_data");
 		margin_operation(tmaid);
 	}
 }
@@ -409,9 +447,10 @@ void command_tab(gpointer callback_data,guint callback_action,
 
 	if (misc_message_box("Text maid",_("Convert Tab to Space?"),1,
 												_("_Yes"),_("_No"),NULL)==0) {
-		tmaid=gtk_object_get_user_data(GTK_OBJECT(
-				gtk_notebook_get_nth_page(GTK_NOTEBOOK(notebook),
-					gtk_notebook_get_current_page(GTK_NOTEBOOK(notebook)))));
+		tmaid = g_object_get_data (G_OBJECT
+				(gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook),
+					gtk_notebook_get_current_page (GTK_NOTEBOOK (notebook)))),
+																"user_data");
 		tab_operation(tmaid);
 	}
 }
@@ -426,9 +465,10 @@ void command_valchr(gpointer callback_data,guint callback_action,
 	GdkPoint select;
 
 	if (valchr_dialog(&valchr)) {
-		tmaid=gtk_object_get_user_data(GTK_OBJECT(
-				gtk_notebook_get_nth_page(GTK_NOTEBOOK(notebook),
-					gtk_notebook_get_current_page(GTK_NOTEBOOK(notebook)))));
+		tmaid = g_object_get_data (G_OBJECT
+				(gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook),
+					gtk_notebook_get_current_page (GTK_NOTEBOOK (notebook)))),
+																"user_data");
 		select=tmaid->select;
 		d=edit_operation(tmaid,&valchr,1,TRUE,FALSE);
 		d->next=tmaid->undo;
@@ -446,9 +486,10 @@ void command_jump(gpointer callback_data,guint callback_action,
 	JumpDialog jmp;
 	TmaidWindow *tmaid;
 
-	tmaid=gtk_object_get_user_data(GTK_OBJECT(
-				gtk_notebook_get_nth_page(GTK_NOTEBOOK(notebook),
-					gtk_notebook_get_current_page(GTK_NOTEBOOK(notebook)))));
+	tmaid = gtk_object_get_data (GTK_OBJECT
+				(gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook),
+					gtk_notebook_get_current_page (GTK_NOTEBOOK (notebook)))),
+																"user_data");
 	jmp.max=tmaid->max;
 	jmp.cursor=tmaid->cursor.y+1;
 	if (jump_dialog(&jmp) && tmaid->cursor.y!=jmp.cursor-1)
@@ -463,9 +504,10 @@ void command_all(gpointer callback_data,guint callback_action,
 	GdkPoint top;
 	TmaidWindow *tmaid;
 
-	tmaid=gtk_object_get_user_data(GTK_OBJECT(
-				gtk_notebook_get_nth_page(GTK_NOTEBOOK(notebook),
-					gtk_notebook_get_current_page(GTK_NOTEBOOK(notebook)))));
+	tmaid = g_object_get_data (G_OBJECT
+				(gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook),
+					gtk_notebook_get_current_page (GTK_NOTEBOOK (notebook)))),
+																"user_data");
 	if (tmaid->max<=1 && tmaid->start->length<=0)
 		return;
 	top=tmaid->top;
@@ -485,11 +527,13 @@ void command_all(gpointer callback_data,guint callback_action,
 		tmaid->top.y=tmaid->cursor.y-sy+1;
 	set_menu_bar(tmaid);
 	if (tmaid->top.x!=top.x)
-		misc_set_scroll_bar(tmaid->hscroll,signal_value_changed_hscroll,tmaid,
-								0,edit_get_width_max(tmaid)+1,sx,tmaid->top.x);
+		misc_set_scroll_bar (tmaid->hscroll,
+						G_CALLBACK (signal_value_changed_hscroll), tmaid,
+						0, edit_get_width_max (tmaid) + 1, sx, tmaid->top.x);
 	if (tmaid->top.y!=top.y)
-		misc_set_scroll_bar(tmaid->vscroll,signal_value_changed_vscroll,tmaid,
-								0,tmaid->max,sy,tmaid->top.y);
+		misc_set_scroll_bar(tmaid->vscroll,
+						G_CALLBACK (signal_value_changed_vscroll), tmaid,
+						0, tmaid->max, sy, tmaid->top.y);
 	gtk_widget_draw(tmaid->drawing,NULL);
 }
 
@@ -502,9 +546,10 @@ void command_find(gpointer callback_data,guint callback_action,
 	FindString fd;
 	TmaidWindow *tmaid;
 
-	tmaid=gtk_object_get_user_data(GTK_OBJECT(
-				gtk_notebook_get_nth_page(GTK_NOTEBOOK(notebook),
-					gtk_notebook_get_current_page(GTK_NOTEBOOK(notebook)))));
+	tmaid = g_object_get_data (G_OBJECT
+				(gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook),
+					gtk_notebook_get_current_page (GTK_NOTEBOOK (notebook)))),
+																"user_data");
 	fd.text=NULL;
 	fd.arrow=find_arrow;
 	fd.ignorecase=find_ignorecase;
@@ -549,9 +594,10 @@ void command_next(gpointer callback_data,guint callback_action,
 	gchar *text;
 	TmaidWindow *tmaid;
 
-	tmaid=gtk_object_get_user_data(GTK_OBJECT(
-				gtk_notebook_get_nth_page(GTK_NOTEBOOK(notebook),
-					gtk_notebook_get_current_page(GTK_NOTEBOOK(notebook)))));
+	tmaid = g_object_get_data (G_OBJECT
+				(gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook),
+					gtk_notebook_get_current_page (GTK_NOTEBOOK (notebook)))),
+																"user_data");
 	find_operation(tmaid,&tmaid->cursor,&tmaid->select,find_text[0],
 					callback_action==0?find_arrow:!find_arrow,find_ignorecase);
 	if (userbreak && tmaid->select.x<0) {
@@ -575,9 +621,10 @@ void command_replace(gpointer callback_data,guint callback_action,
 	ReplaceInfo ri;
 	ReplaceString rp;
 
-	tmaid=gtk_object_get_user_data(GTK_OBJECT(
-				gtk_notebook_get_nth_page(GTK_NOTEBOOK(notebook),
-					gtk_notebook_get_current_page(GTK_NOTEBOOK(notebook)))));
+	tmaid = g_object_get_data (G_OBJECT
+				(gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook),
+					gtk_notebook_get_current_page (GTK_NOTEBOOK (notebook)))),
+																"user_data");
 	rp.src=rp.dst=NULL;
 	rp.arrow=replace_arrow;
 	rp.ignorecase=replace_ignorecase;
