@@ -113,26 +113,27 @@ void conf_dialog(void)
 	height=gdk_screen_height();
 
 	/* ᥤ󥦥ɥ */
-	dialog=gtk_window_new(GTK_WINDOW_DIALOG);
+	dialog = gtk_window_new (GTK_WINDOW_TOPLEVEL);
 	gtk_window_set_title(GTK_WINDOW(dialog),_("Configuration"));
-	gtk_signal_connect_after(GTK_OBJECT(dialog),"key-press-event",
-								GTK_SIGNAL_FUNC(conf_dialog_key_press),NULL);
-	gtk_signal_connect(GTK_OBJECT(dialog),"destroy",gtk_main_quit,NULL);
+	g_signal_connect_after (G_OBJECT(dialog), "key-press-event",
+									G_CALLBACK (conf_dialog_key_press), NULL);
+	g_signal_connect (G_OBJECT (dialog), "destroy",
+											G_CALLBACK (gtk_main_quit), NULL);
 	/* 졼 */
 	accel=gtk_accel_group_new();
-	gtk_accel_group_attach(accel,GTK_OBJECT(dialog));
+	gtk_window_add_accel_group (GTK_WINDOW (dialog), accel);
 	/* ܥ */
 	button0=gtk_button_new_with_label(_("OK"));
 	button1=gtk_button_new_with_label(_("Cancel"));
-	gtk_signal_connect(GTK_OBJECT(button0),"clicked",
-												conf_dialog_clicked,dialog);
-	gtk_signal_connect_object(GTK_OBJECT(button1),"clicked",
-										gtk_widget_destroy,GTK_OBJECT(dialog));
+	g_signal_connect (G_OBJECT (button0), "clicked",
+									G_CALLBACK (conf_dialog_clicked), dialog);
+	g_signal_connect_swapped (G_OBJECT (button1), "clicked",
+						G_CALLBACK (gtk_widget_destroy), G_OBJECT (dialog));
 	GTK_WIDGET_SET_FLAGS(button0,GTK_CAN_DEFAULT);
 	GTK_WIDGET_SET_FLAGS(button1,GTK_CAN_DEFAULT);
 	/* åܥ */
-	check0=gtk_check_button_new_with_label(NULL);
-	check1=gtk_check_button_new_with_label(NULL);
+	check0 = gtk_check_button_new_with_label ("");
+	check1 = gtk_check_button_new_with_label ("");
 	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(check0)->child),
 															_("_New File"));
 	gtk_widget_add_accelerator(check0,"clicked",accel,key,GDK_MOD1_MASK,0);
@@ -141,8 +142,10 @@ void conf_dialog(void)
 	gtk_widget_add_accelerator(check1,"clicked",accel,key,GDK_MOD1_MASK,0);
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check0),newfile);
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check1),second);
-	gtk_signal_connect(GTK_OBJECT(check0),"toggled",conf_dialog_toggled,NULL);
-	gtk_signal_connect(GTK_OBJECT(check1),"toggled",conf_dialog_toggled,NULL);
+	g_signal_connect (G_OBJECT (check0), "toggled",
+									G_CALLBACK (conf_dialog_toggled), NULL);
+	g_signal_connect (G_OBJECT (check1), "toggled",
+									G_CALLBACK (conf_dialog_toggled), NULL);
 	/* ԥܥ */
 	spin0=gtk_spin_button_new(
 			GTK_ADJUSTMENT(gtk_adjustment_new(history,0,10,1,5,0)),0,0);
@@ -153,22 +156,22 @@ void conf_dialog(void)
 	gtk_spin_button_set_numeric(GTK_SPIN_BUTTON(spin0),TRUE);
 	gtk_spin_button_set_numeric(GTK_SPIN_BUTTON(spin1),TRUE);
 	gtk_spin_button_set_numeric(GTK_SPIN_BUTTON(spin2),TRUE);
-	gtk_spin_button_set_shadow_type(GTK_SPIN_BUTTON(spin0),GTK_SHADOW_IN);
-	gtk_spin_button_set_shadow_type(GTK_SPIN_BUTTON(spin1),GTK_SHADOW_IN);
-	gtk_spin_button_set_shadow_type(GTK_SPIN_BUTTON(spin2),GTK_SHADOW_IN);
-	gtk_signal_connect(GTK_OBJECT(spin0),"activate",
-												conf_dialog_activate,dialog);
-	gtk_signal_connect(GTK_OBJECT(spin1),"activate",
-												conf_dialog_activate,dialog);
-	gtk_signal_connect(GTK_OBJECT(spin2),"activate",
-												conf_dialog_activate,dialog);
-	gtk_signal_connect(GTK_OBJECT(spin0),"changed",conf_dialog_changed,NULL);
-	gtk_signal_connect(GTK_OBJECT(spin1),"changed",conf_dialog_changed,NULL);
-	gtk_signal_connect(GTK_OBJECT(spin2),"changed",conf_dialog_changed,NULL);
+	g_signal_connect (G_OBJECT (spin0), "activate",
+									G_CALLBACK (conf_dialog_activate), dialog);
+	g_signal_connect (G_OBJECT (spin1), "activate",
+									G_CALLBACK (conf_dialog_activate), dialog);
+	g_signal_connect (G_OBJECT (spin2), "activate",
+									G_CALLBACK (conf_dialog_activate), dialog);
+	g_signal_connect (G_OBJECT (spin0), "changed",
+									G_CALLBACK (conf_dialog_changed), NULL);
+	g_signal_connect (G_OBJECT (spin1), "changed",
+									G_CALLBACK (conf_dialog_changed), NULL);
+	g_signal_connect (G_OBJECT (spin2), "changed",
+									G_CALLBACK (conf_dialog_changed), NULL);
 	/* ٥ */
-	label0=gtk_label_new(NULL);
-	label1=gtk_label_new(NULL);
-	label2=gtk_label_new(NULL);
+	label0 = gtk_label_new ("");
+	label1 = gtk_label_new ("");
+	label2 = gtk_label_new ("");
 	key=gtk_label_parse_uline(GTK_LABEL(label0),_("H_istory"));
 	gtk_widget_add_accelerator(spin0,"grab-focus",accel,key,GDK_MOD1_MASK,0);
 	key=gtk_label_parse_uline(GTK_LABEL(label1),_("_Width"));
@@ -176,13 +179,13 @@ void conf_dialog(void)
 	key=gtk_label_parse_uline(GTK_LABEL(label2),_("_Height"));
 	gtk_widget_add_accelerator(spin2,"grab-focus",accel,key,GDK_MOD1_MASK,0);
 	/* 饸ܥ */
-	radio0=gtk_radio_button_new_with_label(NULL,NULL);
-	radio1=gtk_radio_button_new_with_label_from_widget(
-												GTK_RADIO_BUTTON(radio0),NULL);
-	radio2=gtk_radio_button_new_with_label_from_widget(
-												GTK_RADIO_BUTTON(radio1),NULL);
-	radio3=gtk_radio_button_new_with_label_from_widget(
-												GTK_RADIO_BUTTON(radio2),NULL);
+	radio0 = gtk_radio_button_new_with_label (NULL, "");
+	radio1 = gtk_radio_button_new_with_label_from_widget (
+												GTK_RADIO_BUTTON (radio0), "");
+	radio2 = gtk_radio_button_new_with_label_from_widget(
+												GTK_RADIO_BUTTON (radio1), "");
+	radio3 = gtk_radio_button_new_with_label_from_widget(
+												GTK_RADIO_BUTTON (radio2), "");
 	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(radio0)->child),_("_Top"));
 	gtk_widget_add_accelerator(radio0,"clicked",accel,key,GDK_MOD1_MASK,0);
 	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(radio1)->child),_("_Left"));
@@ -201,10 +204,14 @@ void conf_dialog(void)
 		case GTK_POS_BOTTOM:gtk_toggle_button_set_active(
 										GTK_TOGGLE_BUTTON(radio3),TRUE);
 	}
-	gtk_signal_connect(GTK_OBJECT(radio0),"toggled",conf_dialog_toggled,NULL);
-	gtk_signal_connect(GTK_OBJECT(radio1),"toggled",conf_dialog_toggled,NULL);
-	gtk_signal_connect(GTK_OBJECT(radio2),"toggled",conf_dialog_toggled,NULL);
-	gtk_signal_connect(GTK_OBJECT(radio3),"toggled",conf_dialog_toggled,NULL);
+	g_signal_connect (G_OBJECT (radio0), "toggled",
+									G_CALLBACK (conf_dialog_toggled), NULL);
+	g_signal_connect (G_OBJECT (radio1), "toggled",
+									G_CALLBACK (conf_dialog_toggled), NULL);
+	g_signal_connect (G_OBJECT (radio2), "toggled",
+									G_CALLBACK (conf_dialog_toggled), NULL);
+	g_signal_connect (G_OBJECT (radio3), "toggled",
+									G_CALLBACK (conf_dialog_toggled), NULL);
 	/* ե졼ȥܥå */
 	frame0=gtk_frame_new(_("Window Size"));
 	hbox0=gtk_hbox_new(FALSE,8);
