@@ -63,8 +63,8 @@ gint edit_get_width(TmaidWindow *tmaid,const gint y)
 			} else if (data_pos+charset_length(p->text[data_pos])<=p->length) {
 				if (data_pos+charset_length(p->text[data_pos])==p->length)
 					break;
-				width+=charset_width(tmaid->font,
-										p->text+data_pos,tmaid->font_width);
+				width += charset_width (tmaid->layout, p->text + data_pos,
+										tmaid->font_width, tmaid->font_buf);
 				data_pos+=charset_length(p->text[data_pos]);
 			} else {
 				width++;
@@ -76,8 +76,8 @@ gint edit_get_width(TmaidWindow *tmaid,const gint y)
 				width=(width/tmaid->ft.tab+1)*tmaid->ft.tab;
 				data_pos++;
 			} else if (data_pos+charset_length(p->text[data_pos])<=p->length) {
-				width+=charset_width(tmaid->font,
-										p->text+data_pos,tmaid->font_width);
+				width += charset_width (tmaid->layout, p->text + data_pos,
+										tmaid->font_width, tmaid->font_buf);
 				data_pos+=charset_length(p->text[data_pos]);
 			} else {
 				width++;
@@ -105,8 +105,8 @@ gint edit_get_width_max(TmaidWindow *tmaid)
 				width=(width/tmaid->ft.tab+1)*tmaid->ft.tab;
 				data_pos++;
 			} else if (data_pos+charset_length(p->text[data_pos])<=p->length) {
-				width+=charset_width(tmaid->font,
-										p->text+data_pos,tmaid->font_width);
+				width += charset_width (tmaid->layout, p->text + data_pos,
+										tmaid->font_width, tmaid->font_buf);
 				data_pos+=charset_length(p->text[data_pos]);
 			} else {
 				width++;
@@ -145,13 +145,14 @@ gint edit_get_align_pos(TmaidWindow *tmaid,const gint x,const gint y,
 				data_pos++;
 			} else if (data_pos+charset_length(p->text[data_pos])==p->length) {
 				break;
-			} else if (x<screen_pos+charset_width(tmaid->font,
-										p->text+data_pos,tmaid->font_width)) {
-				return align?screen_pos+charset_width(tmaid->font,
-								p->text+data_pos,tmaid->font_width):screen_pos;
+			} else if (x < screen_pos + charset_width (tmaid->layout,
+					p->text + data_pos, tmaid->font_width, tmaid->font_buf)) {
+				return align ? screen_pos + charset_width (tmaid->layout,
+						p->text + data_pos, tmaid->font_width, tmaid->font_buf)
+																: screen_pos;
 			} else {
-				screen_pos+=charset_width(tmaid->font,
-										p->text+data_pos,tmaid->font_width);
+				screen_pos += charset_width (tmaid->layout, p->text + data_pos,
+										tmaid->font_width, tmaid->font_buf);
 				data_pos+=charset_length(p->text[data_pos]);
 			}
 	else
@@ -165,13 +166,14 @@ gint edit_get_align_pos(TmaidWindow *tmaid,const gint x,const gint y,
 			} else if (data_pos+charset_length(p->text[data_pos])>p->length) {
 				screen_pos++;
 				data_pos++;
-			} else if (x<screen_pos+charset_width(tmaid->font,
-										p->text+data_pos,tmaid->font_width)) {
-				return align?screen_pos+charset_width(tmaid->font,
-								p->text+data_pos,tmaid->font_width):screen_pos;
+			} else if (x < screen_pos + charset_width (tmaid->layout,
+					p->text + data_pos, tmaid->font_width, tmaid->font_buf)) {
+				return align ? screen_pos + charset_width (tmaid->layout,
+						p->text + data_pos, tmaid->font_width, tmaid->font_buf)
+																: screen_pos;
 			} else {
-				screen_pos+=charset_width(tmaid->font,
-										p->text+data_pos,tmaid->font_width);
+				screen_pos += charset_width (tmaid->layout, p->text + data_pos,
+										tmaid->font_width, tmaid->font_buf);
 				data_pos+=charset_length(p->text[data_pos]);
 			}
 	return screen_pos;
@@ -200,12 +202,12 @@ gint edit_get_data_pos(TmaidWindow *tmaid,const gint x,const gint y,
 		} else if (data_pos+charset_length(p->text[data_pos])>p->length) {
 			screen_pos++;
 			data_pos++;
-		} else if (x<screen_pos+charset_width(tmaid->font,
-										p->text+data_pos,tmaid->font_width)) {
+		} else if (x < screen_pos + charset_width (tmaid->layout,
+					p->text + data_pos, tmaid->font_width, tmaid->font_buf)) {
 			return align?data_pos+charset_length(p->text[data_pos]):data_pos;
 		} else {
-			screen_pos+=charset_width(tmaid->font,
-										p->text+data_pos,tmaid->font_width);
+			screen_pos += charset_width (tmaid->layout, p->text + data_pos,
+										tmaid->font_width, tmaid->font_buf);
 			data_pos+=charset_length(p->text[data_pos]);
 		}
 	return MIN(data_pos,p->length);
@@ -228,8 +230,8 @@ gint edit_get_screen_pos(TmaidWindow *tmaid,const gint x,const gint y)
 			screen_pos=(screen_pos/tmaid->ft.tab+1)*tmaid->ft.tab;
 			data_pos++;
 		} else if (data_pos+charset_length(p->text[data_pos])<=x) {
-			screen_pos+=charset_width(tmaid->font,
-										p->text+data_pos,tmaid->font_width);
+			screen_pos += charset_width (tmaid->layout, p->text + data_pos,
+										tmaid->font_width, tmaid->font_buf);
 			data_pos+=charset_length(p->text[data_pos]);
 		} else {
 			break;
@@ -244,7 +246,7 @@ gint edit_get_screen_pos(TmaidWindow *tmaid,const gint x,const gint y)
 	   RET,ʬ																*/
 guint edit_get_char_type(const gchar *text,const gint length)
 {
-	return charset_type(text,length)&~(CS_CONTROL|CS_SPACE|CS_PUNCT|CS_SYMBOL);
+	return charset_type (text, length);
 }
 
 
@@ -436,8 +438,8 @@ gint edit_put_mem(TmaidWindow *tmaid,GdkPoint *put,GdkPoint *new,
 			if (p->text[data_pos]=='\t')
 				screen_pos=(screen_pos/tmaid->ft.tab+1)*tmaid->ft.tab;
 			else if (data_pos+charset_length(text[data_pos])<=length)
-				screen_pos+=charset_width(tmaid->font,
-										p->text+data_pos,tmaid->font_width);
+				screen_pos += charset_width (tmaid->layout, p->text + data_pos,
+										tmaid->font_width, tmaid->font_buf);
 			else
 				screen_pos++;
 		while (i<length) {
@@ -449,8 +451,9 @@ gint edit_put_mem(TmaidWindow *tmaid,GdkPoint *put,GdkPoint *new,
 						break;
 					data_pos++;
 				} else if (data_pos+charset_length(text[data_pos])<=length) {
-					screen_pos+=charset_width(tmaid->font,
-										p->text+data_pos,tmaid->font_width);
+					screen_pos += charset_width (tmaid->layout,
+										p->text + data_pos,
+										tmaid->font_width, tmaid->font_buf);
 					if (tmaid->ft.margin<screen_pos)
 						break;
 					data_pos+=charset_length(text[data_pos]);
@@ -527,20 +530,22 @@ gint edit_put_mem(TmaidWindow *tmaid,GdkPoint *put,GdkPoint *new,
 				new->x=(new->x/tmaid->ft.tab+1)*tmaid->ft.tab;
 				data_pos++;
 			} else if (data_pos+charset_length(p->text[data_pos])<=p->length) {
-				new->x+=charset_width(tmaid->font,
-										p->text+data_pos,tmaid->font_width);
+				new->x += charset_width (tmaid->layout, p->text + data_pos,
+										tmaid->font_width, tmaid->font_buf);
 				data_pos+=charset_length(p->text[data_pos]);
 			} else {
 				new->x++;
 				data_pos++;
 			}
 		new->y=put->y+insert;
-		if (tmaid->ft.limit && p->margin && (tmaid->ft.margin<=new->x
-				|| (temp!=NULL && tmaid->ft.margin<=new->x
-						+charset_width(tmaid->font,temp,tmaid->font_width)))) {
-			new->x=0;
+		if (tmaid->ft.limit && p->margin && (tmaid->ft.margin <= new->x
+				|| (temp != NULL && tmaid->ft.margin <= new->x
+										+ charset_width (tmaid->layout, temp,
+										tmaid->font_width, tmaid->font_buf))))
+		  {
+			new->x = 0;
 			new->y++;
-		}
+		  }
 	}
 	if (temp!=NULL) {
 		/* ְʹߤʸ᤹ */
@@ -560,8 +565,8 @@ gint edit_put_mem(TmaidWindow *tmaid,GdkPoint *put,GdkPoint *new,
 						break;
 					data_pos++;
 				} else if (data_pos+charset_length(text[data_pos])<=length) {
-					screen_pos+=charset_width(tmaid->font,
-											text+data_pos,tmaid->font_width);
+					screen_pos += charset_width (tmaid->layout,
+						text + data_pos, tmaid->font_width, tmaid->font_buf);
 					if (tmaid->ft.margin<screen_pos)
 						break;
 					data_pos+=charset_length(text[data_pos]);
@@ -669,8 +674,9 @@ gint edit_del_sel_mem(TmaidWindow *tmaid,GdkPoint *start_p,GdkPoint *end_p)
 					data_pos++;
 				} else if (data_pos+charset_length(q->text[data_pos])
 																<=q->length) {
-					screen_pos+=charset_width(tmaid->font,
-										q->text+data_pos,tmaid->font_width);
+					screen_pos += charset_width (tmaid->layout, 
+										q->text + data_pos,
+										tmaid->font_width, tmaid->font_buf);
 					data_pos+=charset_length(q->text[data_pos]);
 				} else {
 					screen_pos++;
@@ -679,8 +685,8 @@ gint edit_del_sel_mem(TmaidWindow *tmaid,GdkPoint *start_p,GdkPoint *end_p)
 			if (p->text[0]=='\t')
 				screen_pos=(screen_pos/tmaid->ft.tab+1)*tmaid->ft.tab;
 			else if (charset_length(p->text[0])<=p->length)
-				screen_pos+=charset_width(tmaid->font,
-													p->text,tmaid->font_width);
+				screen_pos += charset_width (tmaid->layout, p->text,
+										tmaid->font_width, tmaid->font_buf);
 			else
 				screen_pos++;
 		} else {
@@ -721,8 +727,9 @@ gint edit_del_sel_mem(TmaidWindow *tmaid,GdkPoint *start_p,GdkPoint *end_p)
 					data_pos++;
 				} else if (data_pos+charset_length(p->text[data_pos])
 																<=p->length) {
-					screen_pos+=charset_width(tmaid->font,
-										p->text+data_pos,tmaid->font_width);
+					screen_pos += charset_width (tmaid->layout,
+										p->text + data_pos,
+										tmaid->font_width, tmaid->font_buf);
 					if (tmaid->ft.margin<screen_pos)
 						break;
 					data_pos+=charset_length(p->text[data_pos]);
