@@ -22,7 +22,7 @@
 #include "edit.h"
 #include "find.h"
 #include "general.h"
-#include "signal.h"
+#include "sigfile.h"
 #include "misc/misc.h"
 
 
@@ -139,23 +139,22 @@ void find_operation(TmaidWindow *tmaid,GdkPoint *start,GdkPoint *end,
 						&& (data.y<ed.y || (data.y==ed.y && data.x<ed.x))) {
 				if (data.x<q->length) {
 					/* ʸ */
-					if (data.x + charset_length (q->text[data.x]) <= q->length)
-					  {
-						g_memmove (text + length1, q->text + data.x,
-							charset_length (q->text[data.x]) * sizeof (gchar));
+					if (data.x + charset_length (q->text[data.x])
+																<= q->length) {
+						g_memmove(text+length1,q->text+data.x,
+											charset_length (q->text[data.x])
+															* sizeof(gchar));
 						for (i = 0; i < charset_length (q->text[data.x]); i++)
 							buf[i + length1]
 											= charset_length (q->text[data.x]);
 						length1 += charset_length (q->text[data.x]);
 						data.x += charset_length (q->text[data.x]);
-					  }
-					else
-					  {
-						text[length1] = q->text[data.x];
-						buf[length1] = 1;
+					} else {
+						text[length1]=q->text[data.x];
+						buf[length1]=1;
 						length1++;
 						data.x++;
-					  }
+					}
 				} else {
 					/*  */
 					while (gtk_events_pending())
@@ -301,10 +300,12 @@ void find_operation(TmaidWindow *tmaid,GdkPoint *start,GdkPoint *end,
 		else if (tmaid->cursor.y-sy+1>tmaid->top.y)
 			tmaid->top.y=tmaid->cursor.y-sy+1;
 		move_edit_window(tmaid,&top);
-		misc_set_scroll_bar(tmaid->hscroll,signal_value_changed_hscroll,tmaid,
-								0,edit_get_width_max(tmaid)+1,sx,tmaid->top.x);
-		misc_set_scroll_bar(tmaid->vscroll,signal_value_changed_vscroll,tmaid,
-								0,tmaid->max,sy,tmaid->top.y);
+		misc_set_scroll_bar (tmaid->hscroll,
+						G_CALLBACK (signal_value_changed_hscroll), tmaid,
+						0, edit_get_width_max (tmaid) + 1, sx, tmaid->top.x);
+		misc_set_scroll_bar (tmaid->vscroll,
+						G_CALLBACK (signal_value_changed_vscroll), tmaid,
+						0, tmaid->max, sy, tmaid->top.y);
 		clear_sel(tmaid,&tmaid->select,&tmaid->cursor);
 		draw_caret(tmaid,&cursor);
 		gtk_selection_owner_set(tmaid->drawing,GDK_SELECTION_PRIMARY,
@@ -368,26 +369,28 @@ gboolean find_dialog(FindString *fd)
 	GtkWidget *radio0,*button0,*button1,*frame0,*frame1,*hbox,*tbox,*vbox;
 
 	/* ᥤ󥦥ɥ */
-	dialog=gtk_window_new(GTK_WINDOW_DIALOG);
+	dialog = gtk_window_new (GTK_WINDOW_TOPLEVEL);
 	gtk_window_set_title(GTK_WINDOW(dialog),_("Find"));
-	gtk_signal_connect_after(GTK_OBJECT(dialog),"key-press-event",
-								GTK_SIGNAL_FUNC(find_dialog_key_press),NULL);
-	gtk_signal_connect(GTK_OBJECT(dialog),"destroy",gtk_main_quit,NULL);
+	g_signal_connect_after (G_OBJECT (dialog), "key-press-event",
+									G_CALLBACK (find_dialog_key_press), NULL);
+	g_signal_connect (G_OBJECT (dialog), "destroy",
+											G_CALLBACK (gtk_main_quit), NULL);
 	/* 졼 */
 	accel=gtk_accel_group_new();
-	gtk_accel_group_attach(accel,GTK_OBJECT(dialog));
+	gtk_window_add_accel_group (GTK_WINDOW (dialog), accel);
 	/* ܥ */
-	button0=gtk_button_new_with_label(NULL);
+	button0 = gtk_button_new_with_label ("");
 	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(button0)->child),_("_Find"));
 	gtk_widget_add_accelerator(button0,"clicked",accel,key,GDK_MOD1_MASK,0);
 	button1=gtk_button_new_with_label(_("Cancel"));
-	gtk_signal_connect(GTK_OBJECT(button0),"clicked",find_dialog_clicked,fd);
-	gtk_signal_connect_object(GTK_OBJECT(button1),"clicked",
-										gtk_widget_destroy,GTK_OBJECT(dialog));
+	g_signal_connect (G_OBJECT (button0), "clicked",
+										G_CALLBACK (find_dialog_clicked), fd);
+	g_signal_connect_swapped (G_OBJECT (button1), "clicked",
+						G_CALLBACK (gtk_widget_destroy), G_OBJECT (dialog));
 	GTK_WIDGET_SET_FLAGS(button0,GTK_CAN_DEFAULT);
 	GTK_WIDGET_SET_FLAGS(button1,GTK_CAN_DEFAULT);
 	/* åܥ */
-	check=gtk_check_button_new_with_label(NULL);
+	check = gtk_check_button_new_with_label ("");
 	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(check)->child),
 															_("Enable _Case"));
 	gtk_widget_add_accelerator(check,"clicked",accel,key,GDK_MOD1_MASK,0);
@@ -402,14 +405,14 @@ gboolean find_dialog(FindString *fd)
 		gtk_entry_set_text(GTK_ENTRY(GTK_COMBO(combo)->entry),find_text[0]);
 		gtk_editable_select_region(GTK_EDITABLE(GTK_COMBO(combo)->entry),0,-1);
 	}
-	gtk_signal_connect(GTK_OBJECT(GTK_COMBO(combo)->entry),"activate",
-												find_dialog_activate,fd);
-	gtk_signal_connect(GTK_OBJECT(GTK_COMBO(combo)->entry),"changed",
-												find_dialog_changed,button0);
+	g_signal_connect (G_OBJECT (GTK_COMBO (combo)->entry), "activate",
+										G_CALLBACK (find_dialog_activate), fd);
+	g_signal_connect (G_OBJECT (GTK_COMBO (combo)->entry),"changed",
+									G_CALLBACK (find_dialog_changed), button0);
 	/* 饸ܥ */
-	radio0=gtk_radio_button_new_with_label(NULL,NULL);
-	radio1=gtk_radio_button_new_with_label_from_widget(
-												GTK_RADIO_BUTTON(radio0),NULL);
+	radio0 = gtk_radio_button_new_with_label (NULL, "");
+	radio1 = gtk_radio_button_new_with_label_from_widget (
+												GTK_RADIO_BUTTON (radio0), "");
 	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(radio0)->child),_("_Up"));
 	gtk_widget_add_accelerator(radio0,"clicked",accel,key,GDK_MOD1_MASK,0);
 	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(radio1)->child),_("_Down"));
