@@ -1,6 +1,6 @@
 /*
     Text maid
-    copyright (c) 1998-2002 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2003 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -25,28 +25,32 @@
 * ե륿פؿ                                                  *
 *                                                                             *
 ******************************************************************************/
-/* ꥹȥܥå */
-static void ftype_dialog_select_row(GtkWidget *widget,
-				gint row,gint column,GdkEventButton *event,GtkWidget *button)
-{
-	*(gint *)gtk_object_get_user_data(GTK_OBJECT(widget))=row;
-	gtk_widget_set_sensitive(button,TRUE);
-}
+static GtkListStore *store;
 
 
 /* ꥹȥܥå */
-static void ftype_dialog_unselect_row(GtkWidget *widget,
-				gint row,gint column,GdkEventButton *event,GtkWidget *button)
+static void
+ftype_dialog_changed (GtkTreeSelection *select, GtkWidget *button)
 {
-	*(gint *)gtk_object_get_user_data(GTK_OBJECT(widget))=-1;
-	gtk_widget_set_sensitive(button,FALSE);
+	gint i, row = -1;
+	GtkTreeIter iter;
+
+	for (i = 0; gtk_tree_model_iter_nth_child (GTK_TREE_MODEL (store),
+														&iter, NULL, i); i++)
+		if (gtk_tree_selection_iter_is_selected (select, &iter))
+		  {
+			row = i;
+			break;
+  		  }
+	*(gint *)g_object_get_data (G_OBJECT (select), "user_data") = row;
+	gtk_widget_set_sensitive (button, row >= 0);
 }
 
 
 /* OKܥ󤬲줿 */
 static void ftype_dialog_clicked(GtkWidget *widget,GtkWidget *dialog)
 {
-	*(gboolean *)gtk_object_get_user_data(GTK_OBJECT(dialog))=TRUE;
+	*(gboolean *)g_object_get_data (G_OBJECT (dialog), "user_data") = TRUE;
     gtk_widget_destroy(dialog);
 }
 
@@ -64,51 +68,58 @@ static gboolean ftype_dialog_key_press(GtkWidget *widget,GdkEventKey *event,
 gboolean ftype_dialog(gint *pos)
 {
 	gboolean result=FALSE;
-	gchar *text=N_("Independent File Type");
 	gint i,ftpos=-1;
-	GtkWidget *dialog,*clist,*scroll,*hbox,*vbox,*button0,*button1;
+	GtkCellRenderer *renderer;
+	GtkTreeIter iter;
+	GtkTreeSelection *select;
+	GtkTreeViewColumn *column;
+	GtkWidget *dialog,*tview,*scroll,*hbox,*vbox,*button0,*button1;
 
 	/* ᥤ󥦥ɥ */
-	dialog=gtk_window_new(GTK_WINDOW_DIALOG);
+	dialog=gtk_window_new(GTK_WINDOW_TOPLEVEL);
 	gtk_window_set_title(GTK_WINDOW(dialog),_("Associating File Type"));
 	gtk_window_set_default_size(GTK_WINDOW(dialog),320,240);
-	gtk_signal_connect_after(GTK_OBJECT(dialog),"key-press-event",
-								GTK_SIGNAL_FUNC(ftype_dialog_key_press),NULL);
-	gtk_signal_connect(GTK_OBJECT(dialog),"destroy",gtk_main_quit,NULL);
-	gtk_object_set_user_data(GTK_OBJECT(dialog),&result);
+	g_signal_connect_after (G_OBJECT (dialog), "key-press-event",
+									G_CALLBACK (ftype_dialog_key_press), NULL);
+	g_signal_connect (G_OBJECT (dialog), "destroy",
+											G_CALLBACK (gtk_main_quit), NULL);
+	g_object_set_data (G_OBJECT (dialog), "user_data", &result);
 	/* ܥ */
 	button0=gtk_button_new_with_label(_("OK"));
 	button1=gtk_button_new_with_label(_("Cancel"));
-	gtk_signal_connect(GTK_OBJECT(button0),"clicked",
-												ftype_dialog_clicked,dialog);
-	gtk_signal_connect_object(GTK_OBJECT(button1),"clicked",
-										gtk_widget_destroy,GTK_OBJECT(dialog));
+	g_signal_connect (G_OBJECT (button0), "clicked",
+									G_CALLBACK (ftype_dialog_clicked), dialog);
+	g_signal_connect_swapped (G_OBJECT (button1), "clicked",
+						G_CALLBACK (gtk_widget_destroy), G_OBJECT (dialog));
 	GTK_WIDGET_SET_FLAGS(button0,GTK_CAN_DEFAULT);
 	GTK_WIDGET_SET_FLAGS(button1,GTK_CAN_DEFAULT);
 	/* ꥹȥܥå */
-	clist=gtk_clist_new(1);
-	gtk_clist_set_column_title(GTK_CLIST(clist),0,_("Registered File Type"));
-	gtk_clist_column_titles_show(GTK_CLIST(clist));
-	gtk_clist_column_titles_passive(GTK_CLIST(clist));
-	for (i=0;i<ftnum;i++)
-		gtk_clist_append(GTK_CLIST(clist),&ftype[i].text);
-	gtk_clist_append(GTK_CLIST(clist),&text);
-	gtk_clist_set_column_width(GTK_CLIST(clist),0,
-						gtk_clist_optimal_column_width(GTK_CLIST(clist),0));
-	gtk_signal_connect(GTK_OBJECT(clist),"select-row",
-											ftype_dialog_select_row,button0);
-	gtk_signal_connect(GTK_OBJECT(clist),"unselect-row",
-											ftype_dialog_unselect_row,button0);
-	gtk_object_set_user_data(GTK_OBJECT(clist),&ftpos);
+	store = gtk_list_store_new (1, G_TYPE_STRING);
+	tview = gtk_tree_view_new_with_model (GTK_TREE_MODEL (store));
+	renderer = gtk_cell_renderer_text_new ();
+	column = gtk_tree_view_column_new_with_attributes
+						(_("Registered File Type"), renderer, "text", 0, NULL);
+	gtk_tree_view_append_column (GTK_TREE_VIEW (tview), column);
+	select = gtk_tree_view_get_selection (GTK_TREE_VIEW (tview));
+	g_signal_connect (G_OBJECT (select), "changed",
+								G_CALLBACK (ftype_dialog_changed), button0);
+	g_object_set_data (G_OBJECT (select), "user_data", &ftpos);
+	for (i = 0; i < ftnum; i++)
+	  {
+		gtk_list_store_append (store, &iter);
+		gtk_list_store_set (store, &iter, 0, ftype[i].text, -1);
+	  }
+	gtk_list_store_append (store, &iter);
+	gtk_list_store_set (store, &iter, 0, _("Independent File Type"), -1);
 	/* 륦ɥ */
 	scroll=gtk_scrolled_window_new(NULL,NULL);
-	gtk_container_add(GTK_CONTAINER(scroll),clist);
+	gtk_container_add (GTK_CONTAINER (scroll), tview);
 	gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(scroll),
 										GTK_POLICY_NEVER,GTK_POLICY_AUTOMATIC);
 	/* ܥå */
 	vbox=gtk_vbox_new(FALSE,8);
 	gtk_container_set_border_width(GTK_CONTAINER(vbox),8);
-	gtk_box_pack_start(GTK_BOX(vbox),scroll,TRUE,TRUE,8);
+	gtk_box_pack_start(GTK_BOX(vbox),scroll,TRUE,TRUE,0);
 	hbox=gtk_hbox_new(FALSE,8);
 	gtk_box_pack_end(GTK_BOX(hbox),button1,FALSE,FALSE,0);
 	gtk_box_pack_end(GTK_BOX(hbox),button0,FALSE,FALSE,0);
