@@ -21,7 +21,7 @@
 #include "edit.h"
 #include "find.h"
 #include "general.h"
-#include "signal.h"
+#include "sigfile.h"
 #include "toolbar.h"
 #include "misc/misc.h"
 
@@ -99,15 +99,9 @@ void draw_caret(TmaidWindow *tmaid,GdkPoint *cursor)
 	gtk_statusbar_pop(GTK_STATUSBAR(status),context_id);
 	gtk_statusbar_push(GTK_STATUSBAR(status),context_id,text);
 	g_free(text);
-#ifdef USE_XIM
-	if (GTK_WIDGET_HAS_FOCUS(tmaid->drawing)
-				&& gdk_im_ready() && tmaid->ic!=NULL
-				&& (gdk_ic_get_style(tmaid->ic)&GDK_IM_PREEDIT_POSITION)!=0) {
-		tmaid->ic_attr->spot_location.x=rc.x;
-		tmaid->ic_attr->spot_location.y=rc.y+tmaid->font_ascent;
-		gdk_ic_set_attr(tmaid->ic,tmaid->ic_attr,GDK_IC_SPOT_LOCATION);
-	}
-#endif
+	gdk_window_get_origin (tmaid->drawing->window, &x, &y);
+	gtk_window_move (GTK_WINDOW (gtk_widget_get_parent (tmaid->preedit)),
+														rc.x + x, rc.y + y);
 }
 
 
@@ -133,10 +127,8 @@ void set_menu_bar(TmaidWindow *tmaid)
 									"<main>/File/Save As..."),TRUE);
 		gtk_widget_set_sensitive(gtk_item_factory_get_widget(item_factory_menu,
 									"<main>/File/Reload"),!tmaid->create);
-#ifdef USE_GDKPIXBUF
 		gtk_widget_set_sensitive(gtk_item_factory_get_widget(item_factory_menu,
 									"<main>/File/Print..."),TRUE);
-#endif
 		gtk_widget_set_sensitive(gtk_item_factory_get_widget(item_factory_menu,
 									"<main>/File/Properties..."),TRUE);
 		gtk_widget_set_sensitive(gtk_item_factory_get_widget(item_factory_menu,
@@ -155,7 +147,6 @@ void set_menu_bar(TmaidWindow *tmaid)
 									"<main>/Search/Previous"),find_num>0);
 		gtk_widget_set_sensitive(toolbar_items[ 2].item,TRUE);
 		gtk_widget_set_sensitive(toolbar_items[ 4].item,TRUE);
-#ifdef USE_GDKPIXBUF
 		gtk_widget_set_sensitive(toolbar_items[ 6].item,TRUE);
 		gtk_widget_set_sensitive(toolbar_items[ 8].item,tmaid->select.x>=0);
 		gtk_widget_set_sensitive(toolbar_items[ 9].item,tmaid->select.x>=0);
@@ -165,16 +156,6 @@ void set_menu_bar(TmaidWindow *tmaid)
 		gtk_widget_set_sensitive(toolbar_items[14].item,tmaid->redo!=NULL);
 		gtk_widget_set_sensitive(toolbar_items[16].item,TRUE);
 		gtk_widget_set_sensitive(toolbar_items[17].item,TRUE);
-#else
-		gtk_widget_set_sensitive(toolbar_items[ 6].item,tmaid->select.x>=0);
-		gtk_widget_set_sensitive(toolbar_items[ 7].item,tmaid->select.x>=0);
-		gtk_widget_set_sensitive(toolbar_items[ 8].item,TRUE);
-		gtk_widget_set_sensitive(toolbar_items[ 9].item,tmaid->select.x>=0);
-		gtk_widget_set_sensitive(toolbar_items[11].item,tmaid->undo!=NULL);
-		gtk_widget_set_sensitive(toolbar_items[12].item,tmaid->redo!=NULL);
-		gtk_widget_set_sensitive(toolbar_items[14].item,TRUE);
-		gtk_widget_set_sensitive(toolbar_items[15].item,TRUE);
-#endif
 	} else {
 		gtk_widget_set_sensitive(gtk_menu_get_attach_widget(GTK_MENU(
 								gtk_item_factory_get_widget(item_factory_menu,
@@ -190,15 +171,12 @@ void set_menu_bar(TmaidWindow *tmaid)
 									"<main>/File/Save As..."),FALSE);
 		gtk_widget_set_sensitive(gtk_item_factory_get_widget(item_factory_menu,
 									"<main>/File/Reload"),FALSE);
-#ifdef USE_GDKPIXBUF
 		gtk_widget_set_sensitive(gtk_item_factory_get_widget(item_factory_menu,
 									"<main>/File/Print..."),FALSE);
-#endif
 		gtk_widget_set_sensitive(gtk_item_factory_get_widget(item_factory_menu,
 									"<main>/File/Properties..."),FALSE);
 		gtk_widget_set_sensitive(toolbar_items[ 2].item,FALSE);
 		gtk_widget_set_sensitive(toolbar_items[ 4].item,FALSE);
-#ifdef USE_GDKPIXBUF
 		gtk_widget_set_sensitive(toolbar_items[ 6].item,FALSE);
 		gtk_widget_set_sensitive(toolbar_items[ 8].item,FALSE);
 		gtk_widget_set_sensitive(toolbar_items[ 9].item,FALSE);
@@ -208,16 +186,6 @@ void set_menu_bar(TmaidWindow *tmaid)
 		gtk_widget_set_sensitive(toolbar_items[14].item,FALSE);
 		gtk_widget_set_sensitive(toolbar_items[16].item,FALSE);
 		gtk_widget_set_sensitive(toolbar_items[17].item,FALSE);
-#else
-		gtk_widget_set_sensitive(toolbar_items[ 6].item,FALSE);
-		gtk_widget_set_sensitive(toolbar_items[ 7].item,FALSE);
-		gtk_widget_set_sensitive(toolbar_items[ 8].item,FALSE);
-		gtk_widget_set_sensitive(toolbar_items[ 9].item,FALSE);
-		gtk_widget_set_sensitive(toolbar_items[11].item,FALSE);
-		gtk_widget_set_sensitive(toolbar_items[12].item,FALSE);
-		gtk_widget_set_sensitive(toolbar_items[14].item,FALSE);
-		gtk_widget_set_sensitive(toolbar_items[15].item,FALSE);
-#endif
 	}
 	menu=gtk_item_factory_get_widget(item_factory_menu,"<main>/Window");
 	glist=gtk_container_children(GTK_CONTAINER(menu));
@@ -411,10 +379,12 @@ TmaidHistory *edit_operation(TmaidWindow *tmaid,
 	if (tmaid->top.x>max-sx+1)
 		tmaid->top.x=MAX(max-sx+1,0);
 	move_edit_window(tmaid,&top);
-	misc_set_scroll_bar(tmaid->hscroll,signal_value_changed_hscroll,tmaid,
-												0,max+1,sx,tmaid->top.x);
-	misc_set_scroll_bar(tmaid->vscroll,signal_value_changed_vscroll,tmaid,
-												0,tmaid->max,sy,tmaid->top.y);
+	misc_set_scroll_bar (tmaid->hscroll,
+							G_CALLBACK (signal_value_changed_hscroll), tmaid,
+											0, max + 1, sx, tmaid->top.x);
+	misc_set_scroll_bar (tmaid->vscroll,
+							G_CALLBACK (signal_value_changed_vscroll), tmaid,
+											0, tmaid->max, sy, tmaid->top.y);
 	draw_caret(tmaid,NULL);
 	return d;
 }
@@ -463,8 +433,9 @@ void modify_margin(TmaidWindow *tmaid)
 					data_pos++;
 				} else if (data_pos+charset_length(p->text[data_pos])
 																<=p->length) {
-					screen_pos+=charset_width(tmaid->font,
-										p->text+data_pos,tmaid->font_width);
+					screen_pos += charset_width (tmaid->layout, 
+										p->text + data_pos,
+										tmaid->font_width, tmaid->font_buf);
 					if (tmaid->ft.margin<screen_pos)
 						break;
 					data_pos+=charset_length(p->text[data_pos]);
@@ -637,13 +608,15 @@ void margin_operation(TmaidWindow *tmaid)
 	tmaid_change_edit (tmaid, TRUE);
 	tmaid->cursor.x=tmaid->cursor.y=tmaid->top.x=tmaid->top.y=0;
 	tmaid->select.x=-1;
-	misc_set_scroll_bar(tmaid->hscroll,signal_value_changed_hscroll,tmaid,
-				0,edit_get_width_max(tmaid)+1,
-				MAX(tmaid->drawing->allocation.width/tmaid->font_width,1),
+	misc_set_scroll_bar (tmaid->hscroll,
+			G_CALLBACK (signal_value_changed_hscroll), tmaid,
+			0, edit_get_width_max (tmaid) + 1,
+			MAX (tmaid->drawing->allocation.width / tmaid->font_width, 1),
 																tmaid->top.x);
-	misc_set_scroll_bar(tmaid->vscroll,signal_value_changed_vscroll,tmaid,
-				0,tmaid->max,
-				MAX(tmaid->drawing->allocation.height/tmaid->font_height,1),
+	misc_set_scroll_bar (tmaid->vscroll,
+			G_CALLBACK (signal_value_changed_vscroll), tmaid,
+			0, tmaid->max,
+			MAX (tmaid->drawing->allocation.height / tmaid->font_height, 1),
 																tmaid->top.y);
 	set_menu_bar(tmaid);
 	gtk_widget_draw(tmaid->drawing,NULL);
@@ -668,8 +641,8 @@ void tab_operation(TmaidWindow *tmaid)
 				screen_pos=(screen_pos/tmaid->ft.tab+1)*tmaid->ft.tab;
 				data_pos++;
 			} else if (data_pos+charset_length(p->text[data_pos])<=p->length) {
-				screen_pos+=charset_width(tmaid->font,
-										p->text+data_pos,tmaid->font_width);
+				screen_pos += charset_width (tmaid->layout, p->text + data_pos,
+										tmaid->font_width, tmaid->font_buf);
 				data_pos+=charset_length(p->text[data_pos]);
 			} else {
 				screen_pos++;
@@ -687,8 +660,9 @@ void tab_operation(TmaidWindow *tmaid)
 																<=p->length) {
 					g_memmove(temp+screen_pos,p->text+data_pos,
 											charset_length(p->text[data_pos]));
-					screen_pos+=charset_width(tmaid->font,
-										p->text+data_pos,tmaid->font_width);
+					screen_pos += charset_width (tmaid->layout,
+										p->text + data_pos,
+										tmaid->font_width, tmaid->font_buf);
 					data_pos+=charset_length(p->text[data_pos]);
 				} else {
 					temp[screen_pos]=p->text[data_pos];
