@@ -1,6 +1,6 @@
 /*
     Text maid
-    copyright (c) 1998-2002 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2003 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -20,7 +20,7 @@
 #include "edit.h"
 #include "general.h"
 #include "jump.h"
-#include "signal.h"
+#include "sigfile.h"
 #include "misc/misc.h"
 
 
@@ -56,10 +56,12 @@ void jump_operation(TmaidWindow *tmaid,const gint line)
 	else if (tmaid->cursor.y-sy+1>tmaid->top.y)
 		tmaid->top.y=tmaid->cursor.y-sy+1;
 	move_edit_window(tmaid,&top);
-	misc_set_scroll_bar(tmaid->hscroll,signal_value_changed_hscroll,tmaid,
-								0,edit_get_width_max(tmaid)+1,sx,tmaid->top.x);
-	misc_set_scroll_bar(tmaid->vscroll,signal_value_changed_vscroll,tmaid,
-								0,tmaid->max,sy,tmaid->top.y);
+	misc_set_scroll_bar (tmaid->hscroll,
+						G_CALLBACK (signal_value_changed_hscroll), tmaid,
+						0, edit_get_width_max (tmaid) + 1, sx, tmaid->top.x);
+	misc_set_scroll_bar (tmaid->vscroll,
+						G_CALLBACK (signal_value_changed_vscroll), tmaid,
+						0, tmaid->max, sy, tmaid->top.y);
 	if (tmaid->select.x>=0) {
 		if (tmaid->select.y==tmaid->cursor.y
 								&& tmaid->select.x==edit_get_align_pos(tmaid,
@@ -132,17 +134,19 @@ gboolean jump_dialog(JumpDialog *jmp)
 	GtkWidget *button1,*hbox,*vbox;
 
 	/* ᥤ󥦥ɥ */
-	dialog=gtk_window_new(GTK_WINDOW_DIALOG);
+	dialog = gtk_window_new (GTK_WINDOW_TOPLEVEL);
 	gtk_window_set_title(GTK_WINDOW(dialog),_("Jump"));
-	gtk_signal_connect_after(GTK_OBJECT(dialog),"key-press-event",
-								GTK_SIGNAL_FUNC(jump_dialog_key_press),NULL);
-	gtk_signal_connect(GTK_OBJECT(dialog),"destroy",gtk_main_quit,NULL);
+	g_signal_connect_after (G_OBJECT (dialog), "key-press-event",
+									G_CALLBACK (jump_dialog_key_press), NULL);
+	g_signal_connect (G_OBJECT (dialog), "destroy", 
+											G_CALLBACK (gtk_main_quit), NULL);
 	/* ܥ */
 	button0=gtk_button_new_with_label(_("OK"));
 	button1=gtk_button_new_with_label(_("Cancel"));
-	gtk_signal_connect(GTK_OBJECT(button0),"clicked",jump_dialog_clicked,jmp);
-	gtk_signal_connect_object(GTK_OBJECT(button1),"clicked",
-										gtk_widget_destroy,GTK_OBJECT(dialog));
+	g_signal_connect (G_OBJECT (button0), "clicked",
+										G_CALLBACK (jump_dialog_clicked), jmp);
+	g_signal_connect_swapped (G_OBJECT (button1), "clicked",
+						G_CALLBACK (gtk_widget_destroy), G_OBJECT (dialog));
 	GTK_WIDGET_SET_FLAGS(button0,GTK_CAN_DEFAULT);
 	GTK_WIDGET_SET_FLAGS(button1,GTK_CAN_DEFAULT);
 	/* ȥ꡼ */
@@ -150,8 +154,10 @@ gboolean jump_dialog(JumpDialog *jmp)
 	text=misc_str_from_val(jmp->cursor,10,0,FALSE);
 	gtk_entry_set_text(GTK_ENTRY(entry),text);
 	g_free(text);
-	gtk_signal_connect(GTK_OBJECT(entry),"activate",jump_dialog_activate,jmp);
-	gtk_signal_connect(GTK_OBJECT(entry),"changed",jump_dialog_changed,jmp);
+	g_signal_connect (G_OBJECT (entry), "activate",
+									G_CALLBACK (jump_dialog_activate), jmp);
+	g_signal_connect (G_OBJECT (entry), "changed",
+									G_CALLBACK (jump_dialog_changed), jmp);
 	gtk_editable_select_region(GTK_EDITABLE(entry),0,-1);
 	/* ե졼ȥܥå */
 	vbox=gtk_vbox_new(FALSE,8);
