@@ -17,7 +17,6 @@
     Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
 #include "print.h"
-#ifdef USE_GDKPIXBUF
 #include <gdk/gdkkeysyms.h>
 #include <gdk-pixbuf/gdk-pixbuf.h>
 #include "abort.h"
@@ -85,8 +84,8 @@ gboolean print_out(TmaidWindow *tmaid,PrintConfig *prncfg)
 	gdk_gc_set_line_attributes(gc,1,
 								GDK_LINE_SOLID,GDK_CAP_BUTT,GDK_JOIN_MITER);
 	for (i=10;i<12;i++)
-		gdk_color_alloc (gdk_colormap_get_system(),
-					(tmaid->ft.syscol ? system_color : tmaid->ft.color) + i);
+		gdk_color_alloc (gdk_colormap_get_system (), (tmaid->ft.syscol
+										? system_color : tmaid->ft.color) + i);
 	p=edit_get_line_buf(&tmaid->start,&tmaid->off,start.y);
 	end_pos=edit_get_data_pos(tmaid,end.x,end.y,FALSE);
 	line=start.y;
@@ -120,8 +119,9 @@ gboolean print_out(TmaidWindow *tmaid,PrintConfig *prncfg)
 					width=(x/tmaid->font_width/tmaid->ft.tab+1)*tmaid->ft.tab
 														*tmaid->font_width-x;
 				else if (data_pos+charset_length(p->text[data_pos])<=p->length)
-					width=tmaid->font_width*charset_width(tmaid->font,
-										p->text+data_pos,tmaid->font_width);
+					width = tmaid->font_width * charset_width (tmaid->layout,
+										p->text + data_pos,
+										tmaid->font_width, tmaid->font_buf);
 				else
 					width=tmaid->font_width;
 				if (x>0 && sx<x+width)
@@ -132,14 +132,15 @@ gboolean print_out(TmaidWindow *tmaid,PrintConfig *prncfg)
 				} else if (data_pos+charset_length(p->text[data_pos])
 																<=p->length) {
 					/* Ⱦ/ */
-					gdk_draw_text(pixmap,tmaid->font,gc,
-									x,y+tmaid->font_ascent,p->text+data_pos,
-											charset_length(p->text[data_pos]));
-					data_pos+=charset_length(p->text[data_pos]);
+					pango_layout_set_text (tmaid->layout, p->text + data_pos,
+										charset_length (p->text[data_pos]));
+					gdk_draw_layout (pixmap, gc, x, y, tmaid->layout);
+					data_pos += charset_length (p->text[data_pos]);
 				} else {
 					/* Ⱦ */
-					gdk_draw_text(pixmap,tmaid->font,gc,
-									x,y+tmaid->font_ascent,p->text+data_pos,1);
+					pango_layout_set_text (tmaid->layout,
+														p->text + data_pos, 1);
+					gdk_draw_layout (pixmap, gc, x, y, tmaid->layout);
 					data_pos++;
 				}
 				x+=width;
@@ -202,7 +203,7 @@ gboolean print_out(TmaidWindow *tmaid,PrintConfig *prncfg)
 	/* λ */
 	gtk_grab_remove(dialog);
     gtk_widget_destroy(dialog);
-	gdk_gc_destroy(gc);
+	g_object_unref (gc);
 	gdk_pixbuf_unref(pixbuf);
 	gdk_pixmap_unref(pixmap);
 	if (prncfg->mode)	/* ץ */
@@ -278,7 +279,7 @@ static void print_dialog_changed_spin(GtkWidget *widget,PrintConfig *prncfg)
 /* ܥܥå */
 static void print_dialog_changed_combo(GtkWidget *widget,gpointer user_data)
 {
-	gchar *name;
+	const gchar *name;
 	gint i;
 
 	name=gtk_entry_get_text(GTK_ENTRY(widget));
@@ -344,7 +345,7 @@ static void print_open_ok(GtkWidget *widget,GtkWidget *dialog_open)
 {
 	gchar **file;
 
-	file=gtk_object_get_user_data(GTK_OBJECT(dialog_open));
+	file = g_object_get_data (G_OBJECT (dialog_open), "user_data");
 	*file=g_strdup(gtk_file_selection_get_filename(
 											GTK_FILE_SELECTION(dialog_open)));
     gtk_widget_destroy(dialog_open);
@@ -358,15 +359,16 @@ static void print_dialog_clicked_file(GtkWidget *widget,PrintConfig *prncfg)
 	GtkWidget *dialog_open;
 
 	dialog_open=gtk_file_selection_new(_("Save As"));
-	gtk_signal_connect(GTK_OBJECT(dialog_open),"destroy",gtk_main_quit,NULL);
-	gtk_signal_connect(GTK_OBJECT(GTK_FILE_SELECTION(dialog_open)->ok_button),
-										"clicked",print_open_ok,dialog_open);
-	gtk_signal_connect_object(
-					GTK_OBJECT(GTK_FILE_SELECTION(dialog_open)->cancel_button),
-						"clicked",gtk_widget_destroy,GTK_OBJECT(dialog_open));
+	g_signal_connect (G_OBJECT (dialog_open), "destroy",
+											G_CALLBACK (gtk_main_quit), NULL);
+	g_signal_connect (G_OBJECT (GTK_FILE_SELECTION (dialog_open)->ok_button),
+							"clicked",G_CALLBACK (print_open_ok), dialog_open);
+	g_signal_connect_swapped (
+					G_OBJECT (GTK_FILE_SELECTION (dialog_open)->cancel_button),
+			"clicked",G_CALLBACK (gtk_widget_destroy), G_OBJECT (dialog_open));
 	gtk_file_selection_set_filename(GTK_FILE_SELECTION(dialog_open),
 										gtk_entry_get_text(GTK_ENTRY(entry1)));
-	gtk_object_set_user_data(GTK_OBJECT(dialog_open),&file);
+	g_object_set_data (G_OBJECT (dialog_open), "user_data", &file);
 	gtk_widget_show(dialog_open);
 	gtk_grab_add(dialog_open);
 	gtk_main();
@@ -419,33 +421,34 @@ gboolean print_dialog(PrintConfig *prncfg)
 	/* ᥤ󥦥ɥ */
 	dialog=gtk_window_new(GTK_WINDOW_TOPLEVEL);
 	gtk_window_set_title(GTK_WINDOW(dialog),_("Print"));
-	gtk_signal_connect_after(GTK_OBJECT(dialog),"key-press-event",
-								GTK_SIGNAL_FUNC(print_dialog_key_press),NULL);
-	gtk_signal_connect(GTK_OBJECT(dialog),"destroy",gtk_main_quit,NULL);
+	g_signal_connect_after (G_OBJECT (dialog), "key-press-event",
+									G_CALLBACK (print_dialog_key_press), NULL);
+	g_signal_connect (G_OBJECT (dialog), "destroy",
+											G_CALLBACK (gtk_main_quit), NULL);
 	/* 졼 */
 	accel=gtk_accel_group_new();
-	gtk_accel_group_attach(accel,GTK_OBJECT(dialog));
+	gtk_window_add_accel_group (GTK_WINDOW (dialog), accel);
 	/* ܥ */
 	button0=gtk_button_new_with_label(_("Browse..."));
 	button1=gtk_button_new_with_label(_("Print"));
 	button2=gtk_button_new_with_label(_("Cancel"));
-	gtk_signal_connect(GTK_OBJECT(button0),"clicked",
-											print_dialog_clicked_file,dialog);
-	gtk_signal_connect(GTK_OBJECT(button1),"clicked",
-											print_dialog_clicked_ok,prncfg);
-	gtk_signal_connect_object(GTK_OBJECT(button2),"clicked",
-										gtk_widget_destroy,GTK_OBJECT(dialog));
+	g_signal_connect (G_OBJECT (button0), "clicked",
+							G_CALLBACK (print_dialog_clicked_file), dialog);
+	g_signal_connect (G_OBJECT (button1), "clicked",
+								G_CALLBACK (print_dialog_clicked_ok), prncfg);
+	g_signal_connect_swapped (G_OBJECT (button2), "clicked",
+						G_CALLBACK (gtk_widget_destroy), G_OBJECT (dialog));
 	GTK_WIDGET_SET_FLAGS(button0,GTK_CAN_DEFAULT);
 	GTK_WIDGET_SET_FLAGS(button1,GTK_CAN_DEFAULT);
 	GTK_WIDGET_SET_FLAGS(button2,GTK_CAN_DEFAULT);
 	/* åܥ */
-	check=gtk_check_button_new_with_label(NULL);
+	check = gtk_check_button_new_with_label ("");
 	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(check)->child),
 														_("Print _Selection"));
 	gtk_widget_add_accelerator(check,"clicked",accel,key,GDK_MOD1_MASK,0);
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(check),prncfg->select);
-	gtk_signal_connect(GTK_OBJECT(check),"toggled",
-												print_dialog_toggled,prncfg);
+	g_signal_connect (G_OBJECT (check), "toggled",
+									G_CALLBACK (print_dialog_toggled), prncfg);
 	gtk_widget_set_sensitive(check,prncfg->select);
 	/* ȥ꡼ */
 	entry0=gtk_entry_new();
@@ -454,14 +457,14 @@ gboolean print_dialog(PrintConfig *prncfg)
 		gtk_entry_set_text(GTK_ENTRY(entry0),prncfg->printer);
 	if (prncfg->file!=NULL)
 		gtk_entry_set_text(GTK_ENTRY(entry1),prncfg->file);
-	gtk_signal_connect(GTK_OBJECT(entry0),"activate",
-											print_dialog_clicked_ok,prncfg);
-	gtk_signal_connect(GTK_OBJECT(entry1),"activate",
-											print_dialog_clicked_ok,prncfg);
-	gtk_signal_connect(GTK_OBJECT(entry0),"changed",
-											print_dialog_ok_sensitive,prncfg);
-	gtk_signal_connect(GTK_OBJECT(entry1),"changed",
-											print_dialog_ok_sensitive,prncfg);
+	g_signal_connect (G_OBJECT (entry0), "activate",
+							G_CALLBACK (print_dialog_clicked_ok), prncfg);
+	g_signal_connect (G_OBJECT (entry1), "activate",
+							G_CALLBACK (print_dialog_clicked_ok), prncfg);
+	g_signal_connect (G_OBJECT (entry0), "changed",
+							G_CALLBACK (print_dialog_ok_sensitive), prncfg);
+	g_signal_connect (G_OBJECT (entry1), "changed",
+							G_CALLBACK (print_dialog_ok_sensitive), prncfg);
 	/* ԥܥ */
 	spin0=gtk_spin_button_new(GTK_ADJUSTMENT(gtk_adjustment_new(prncfg->column,
 													1,G_MAXINT,1,5,0)),0,0);
@@ -484,64 +487,57 @@ gboolean print_dialog(PrintConfig *prncfg)
 	gtk_spin_button_set_numeric(GTK_SPIN_BUTTON(spin4),TRUE);
 	gtk_spin_button_set_numeric(GTK_SPIN_BUTTON(spin5),TRUE);
 	gtk_spin_button_set_numeric(GTK_SPIN_BUTTON(spin6),TRUE);
-	gtk_spin_button_set_shadow_type(GTK_SPIN_BUTTON(spin0),GTK_SHADOW_IN);
-	gtk_spin_button_set_shadow_type(GTK_SPIN_BUTTON(spin1),GTK_SHADOW_IN);
-	gtk_spin_button_set_shadow_type(GTK_SPIN_BUTTON(spin2),GTK_SHADOW_IN);
-	gtk_spin_button_set_shadow_type(GTK_SPIN_BUTTON(spin3),GTK_SHADOW_IN);
-	gtk_spin_button_set_shadow_type(GTK_SPIN_BUTTON(spin4),GTK_SHADOW_IN);
-	gtk_spin_button_set_shadow_type(GTK_SPIN_BUTTON(spin5),GTK_SHADOW_IN);
-	gtk_spin_button_set_shadow_type(GTK_SPIN_BUTTON(spin6),GTK_SHADOW_IN);
-	gtk_signal_connect(GTK_OBJECT(spin0),"activate",
-												print_dialog_activate,prncfg);
-	gtk_signal_connect(GTK_OBJECT(spin1),"activate",
-												print_dialog_activate,prncfg);
-	gtk_signal_connect(GTK_OBJECT(spin2),"activate",
-												print_dialog_activate,prncfg);
-	gtk_signal_connect(GTK_OBJECT(spin3),"activate",
-												print_dialog_activate,prncfg);
-	gtk_signal_connect(GTK_OBJECT(spin4),"activate",
-												print_dialog_activate,prncfg);
-	gtk_signal_connect(GTK_OBJECT(spin5),"activate",
-												print_dialog_activate,prncfg);
-	gtk_signal_connect(GTK_OBJECT(spin6),"activate",
-												print_dialog_activate,prncfg);
-	gtk_signal_connect(GTK_OBJECT(spin0),"changed",
-											print_dialog_changed_spin,prncfg);
-	gtk_signal_connect(GTK_OBJECT(spin1),"changed",
-											print_dialog_changed_spin,prncfg);
-	gtk_signal_connect(GTK_OBJECT(spin2),"changed",
-											print_dialog_changed_spin,prncfg);
-	gtk_signal_connect(GTK_OBJECT(spin3),"changed",
-											print_dialog_changed_spin,prncfg);
-	gtk_signal_connect(GTK_OBJECT(spin4),"changed",
-											print_dialog_changed_spin,prncfg);
-	gtk_signal_connect(GTK_OBJECT(spin5),"changed",
-											print_dialog_changed_spin,prncfg);
-	gtk_signal_connect(GTK_OBJECT(spin6),"changed",
-											print_dialog_changed_spin,prncfg);
+	g_signal_connect (G_OBJECT(spin0), "activate",
+								G_CALLBACK (print_dialog_activate), prncfg);
+	g_signal_connect (G_OBJECT(spin1), "activate",
+								G_CALLBACK (print_dialog_activate), prncfg);
+	g_signal_connect (G_OBJECT(spin2), "activate",
+								G_CALLBACK (print_dialog_activate), prncfg);
+	g_signal_connect (G_OBJECT(spin3), "activate",
+								G_CALLBACK (print_dialog_activate), prncfg);
+	g_signal_connect (G_OBJECT(spin4), "activate",
+								G_CALLBACK (print_dialog_activate), prncfg);
+	g_signal_connect (G_OBJECT(spin5), "activate",
+								G_CALLBACK (print_dialog_activate), prncfg);
+	g_signal_connect (G_OBJECT(spin6), "activate",
+								G_CALLBACK (print_dialog_activate), prncfg);
+	g_signal_connect (G_OBJECT(spin0), "changed",
+							G_CALLBACK (print_dialog_changed_spin), prncfg);
+	g_signal_connect (G_OBJECT(spin1), "changed",
+							G_CALLBACK (print_dialog_changed_spin), prncfg);
+	g_signal_connect (G_OBJECT(spin2), "changed",
+							G_CALLBACK (print_dialog_changed_spin), prncfg);
+	g_signal_connect (G_OBJECT(spin3), "changed",
+							G_CALLBACK (print_dialog_changed_spin), prncfg);
+	g_signal_connect (G_OBJECT(spin4), "changed",
+							G_CALLBACK (print_dialog_changed_spin), prncfg);
+	g_signal_connect (G_OBJECT(spin5), "changed",
+							G_CALLBACK (print_dialog_changed_spin), prncfg);
+	g_signal_connect (G_OBJECT(spin6), "changed",
+							G_CALLBACK (print_dialog_changed_spin), prncfg);
 	/* 饸ܥ */
-	radio0=gtk_radio_button_new_with_label(NULL,NULL);
-	radio1=gtk_radio_button_new_with_label_from_widget(
-												GTK_RADIO_BUTTON(radio0),NULL);
+	radio0 = gtk_radio_button_new_with_label (NULL, "");
+	radio1 = gtk_radio_button_new_with_label_from_widget (
+												GTK_RADIO_BUTTON (radio0), "");
 	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(radio0)->child),_("_Printer"));
 	gtk_widget_add_accelerator(radio0,"clicked",accel,key,GDK_MOD1_MASK,0);
 	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(radio1)->child),_("_File"));
 	gtk_widget_add_accelerator(radio1,"clicked",accel,key,GDK_MOD1_MASK,0);
-	gtk_signal_connect(GTK_OBJECT(radio0),"toggled",
-												print_dialog_toggled,prncfg);
-	gtk_signal_connect(GTK_OBJECT(radio1),"toggled",
-												print_dialog_toggled,prncfg);
+	g_signal_connect (G_OBJECT (radio0), "toggled",
+									G_CALLBACK (print_dialog_toggled), prncfg);
+	g_signal_connect (G_OBJECT (radio1), "toggled",
+									G_CALLBACK (print_dialog_toggled), prncfg);
 	if (!prncfg->mode)
 		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(radio1),TRUE);
 	/* ٥ */
-	label0=gtk_label_new(NULL);
-	label1=gtk_label_new(NULL);
-	label2=gtk_label_new(NULL);
-	label3=gtk_label_new(NULL);
-	label4=gtk_label_new(NULL);
-	label5=gtk_label_new(NULL);
-	label6=gtk_label_new(NULL);
-	label7=gtk_label_new(NULL);
+	label0 = gtk_label_new ("");
+	label1 = gtk_label_new ("");
+	label2 = gtk_label_new ("");
+	label3 = gtk_label_new ("");
+	label4 = gtk_label_new ("");
+	label5 = gtk_label_new ("");
+	label6 = gtk_label_new ("");
+	label7 = gtk_label_new ("");
 	key=gtk_label_parse_uline(GTK_LABEL(label0),_("_Columns"));
 	gtk_widget_add_accelerator(spin0,"grab-focus",accel,key,GDK_MOD1_MASK,0);
 	key=gtk_label_parse_uline(GTK_LABEL(label2),_("_Width"));
@@ -564,8 +560,8 @@ gboolean print_dialog(PrintConfig *prncfg)
 	gtk_combo_set_popdown_strings(GTK_COMBO(combo),glist);
 	gtk_combo_set_value_in_list(GTK_COMBO(combo),TRUE,FALSE);
 	gtk_editable_set_editable(GTK_EDITABLE(GTK_COMBO(combo)->entry),FALSE);
-	gtk_signal_connect(GTK_OBJECT(GTK_COMBO(combo)->entry),"changed",
-											print_dialog_changed_combo,NULL);
+	g_signal_connect (G_OBJECT (GTK_COMBO (combo)->entry), "changed",
+								G_CALLBACK (print_dialog_changed_combo), NULL);
 	for (i=0;paper[i].name!=NULL;i++)
 		if (paper[i].width==prncfg->width && paper[i].height==prncfg->height)
 			break;
@@ -664,4 +660,3 @@ gboolean print_dialog(PrintConfig *prncfg)
 
 	return print_clicked_ok;
 }
-#endif
