@@ -1,6 +1,6 @@
 /*
     Text maid
-    copyright (c) 1998-2002 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2003 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -29,8 +29,8 @@
 /* ܥ󤬲줿 */
 static void repinfo_dialog_clicked(GtkWidget *widget,GtkWidget *dialog)
 {
-	*(gint *)gtk_object_get_user_data(GTK_OBJECT(dialog))
-						=(gint)gtk_object_get_user_data(GTK_OBJECT(widget));
+	*(gint *)g_object_get_data (G_OBJECT (dialog), "user_data")
+					= (gint)g_object_get_data (G_OBJECT (widget), "user_data");
 	gtk_widget_destroy(dialog);
 }
 
@@ -55,19 +55,20 @@ gint repinfo_dialog(ReplaceInfo *ri)
 	GtkWidget *frame0,*frame1,*hbox,*tbox,*vbox;
 
 	/* ᥤ󥦥ɥ */
-	dialog=gtk_window_new(GTK_WINDOW_DIALOG);
+	dialog = gtk_window_new (GTK_WINDOW_TOPLEVEL);
 	gtk_window_set_title(GTK_WINDOW(dialog),_("Replace Information"));
-	gtk_signal_connect_after(GTK_OBJECT(dialog),"key-press-event",
-							GTK_SIGNAL_FUNC(repinfo_dialog_key_press),NULL);
-	gtk_signal_connect(GTK_OBJECT(dialog),"destroy",gtk_main_quit,NULL);
-	gtk_object_set_user_data(GTK_OBJECT(dialog),&result);
+	g_signal_connect_after (G_OBJECT (dialog), "key-press-event",
+								G_CALLBACK (repinfo_dialog_key_press), NULL);
+	g_signal_connect (G_OBJECT (dialog), "destroy",
+											G_CALLBACK (gtk_main_quit), NULL);
+	g_object_set_data (G_OBJECT (dialog), "user_data", &result);
 	/* 졼 */
 	accel=gtk_accel_group_new();
-	gtk_accel_group_attach(accel,GTK_OBJECT(dialog));
+	gtk_window_add_accel_group (GTK_WINDOW (dialog), accel);
 	/* ܥ */
-	button0=gtk_button_new_with_label(NULL);
-	button1=gtk_button_new_with_label(NULL);
-	button2=gtk_button_new_with_label(NULL);
+	button0 = gtk_button_new_with_label ("");
+	button1 = gtk_button_new_with_label ("");
+	button2 = gtk_button_new_with_label ("");
 	button3=gtk_button_new_with_label(_("Cancel"));
 	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(button0)->child),
 																_("_Replace"));
@@ -76,17 +77,18 @@ gint repinfo_dialog(ReplaceInfo *ri)
 	gtk_widget_add_accelerator(button1,"clicked",accel,key,GDK_MOD1_MASK,0);
 	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(button2)->child),_("_All"));
 	gtk_widget_add_accelerator(button2,"clicked",accel,'A',GDK_MOD1_MASK,0);
-	gtk_signal_connect(GTK_OBJECT(button0),"clicked",
-										repinfo_dialog_clicked,dialog);
-	gtk_signal_connect(GTK_OBJECT(button1),"clicked",
-										repinfo_dialog_clicked,dialog);
-	gtk_signal_connect(GTK_OBJECT(button2),"clicked",
-										repinfo_dialog_clicked,dialog);
-	gtk_signal_connect_object(GTK_OBJECT(button3),"clicked",
-										gtk_widget_destroy,GTK_OBJECT(dialog));
-	gtk_object_set_user_data(GTK_OBJECT(button0),(gpointer)REPLACE_OK);
-	gtk_object_set_user_data(GTK_OBJECT(button1),(gpointer)REPLACE_NEXT);
-	gtk_object_set_user_data(GTK_OBJECT(button2),(gpointer)REPLACE_ALL);
+	g_signal_connect (G_OBJECT (button0), "clicked",
+								G_CALLBACK (repinfo_dialog_clicked), dialog);
+	g_signal_connect (G_OBJECT (button1), "clicked",
+								G_CALLBACK (repinfo_dialog_clicked), dialog);
+	g_signal_connect (G_OBJECT (button2), "clicked",
+								G_CALLBACK (repinfo_dialog_clicked), dialog);
+	g_signal_connect_swapped (G_OBJECT (button3), "clicked",
+						G_CALLBACK (gtk_widget_destroy), G_OBJECT (dialog));
+	g_object_set_data (G_OBJECT (button0), "user_data", (gpointer)REPLACE_OK);
+	g_object_set_data (G_OBJECT (button1), "user_data",
+													(gpointer)REPLACE_NEXT);
+	g_object_set_data (G_OBJECT (button2), "user_data", (gpointer)REPLACE_ALL);
 	GTK_WIDGET_SET_FLAGS(button0,GTK_CAN_DEFAULT);
 	GTK_WIDGET_SET_FLAGS(button1,GTK_CAN_DEFAULT);
 	GTK_WIDGET_SET_FLAGS(button2,GTK_CAN_DEFAULT);
