@@ -1,6 +1,6 @@
 /*
     Text maid
-    copyright (c) 1998-2002 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2003 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -98,34 +98,35 @@ gint replace_dialog(ReplaceString *rp)
 	GtkWidget *frame0,*frame1,*hbox,*tbox,*vbox;
 
 	/* ᥤ󥦥ɥ */
-	dialog=gtk_window_new(GTK_WINDOW_DIALOG);
+	dialog = gtk_window_new (GTK_WINDOW_TOPLEVEL);
 	gtk_window_set_title(GTK_WINDOW(dialog),_("Replace"));
-	gtk_signal_connect_after(GTK_OBJECT(dialog),"key-press-event",
-							GTK_SIGNAL_FUNC(replace_dialog_key_press),NULL);
-	gtk_signal_connect(GTK_OBJECT(dialog),"destroy",gtk_main_quit,NULL);
+	g_signal_connect_after (G_OBJECT (dialog), "key-press-event",
+								G_CALLBACK (replace_dialog_key_press), NULL);
+	g_signal_connect (G_OBJECT (dialog), "destroy",
+											G_CALLBACK (gtk_main_quit), NULL);
 	/* 졼 */
 	accel=gtk_accel_group_new();
-	gtk_accel_group_attach(accel,GTK_OBJECT(dialog));
+	gtk_window_add_accel_group (GTK_WINDOW (dialog), accel);
 	/* ܥ */
-	button0=gtk_button_new_with_label(NULL);
-	button1=gtk_button_new_with_label(NULL);
+	button0 = gtk_button_new_with_label ("");
+	button1 = gtk_button_new_with_label ("");
 	button2=gtk_button_new_with_label(_("Cancel"));
 	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(button0)->child),
 																_("_Replace"));
 	gtk_widget_add_accelerator(button0,"clicked",accel,key,GDK_MOD1_MASK,0);
 	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(button1)->child),_("_All"));
 	gtk_widget_add_accelerator(button1,"clicked",accel,key,GDK_MOD1_MASK,0);
-	gtk_signal_connect(GTK_OBJECT(button0),"clicked",
-												replace_dialog_clicked_ok,rp);
-	gtk_signal_connect(GTK_OBJECT(button1),"clicked",
-												replace_dialog_clicked_all,rp);
-	gtk_signal_connect_object(GTK_OBJECT(button2),"clicked",
-										gtk_widget_destroy,GTK_OBJECT(dialog));
+	g_signal_connect (G_OBJECT (button0), "clicked",
+								G_CALLBACK (replace_dialog_clicked_ok), rp);
+	g_signal_connect (G_OBJECT (button1), "clicked",
+								G_CALLBACK (replace_dialog_clicked_all), rp);
+	g_signal_connect_swapped (G_OBJECT (button2), "clicked",
+						G_CALLBACK (gtk_widget_destroy), G_OBJECT (dialog));
 	GTK_WIDGET_SET_FLAGS(button0,GTK_CAN_DEFAULT);
 	GTK_WIDGET_SET_FLAGS(button1,GTK_CAN_DEFAULT);
 	GTK_WIDGET_SET_FLAGS(button2,GTK_CAN_DEFAULT);
 	/* åܥ */
-	check=gtk_check_button_new_with_label(NULL);
+	check = gtk_check_button_new_with_label ("");
 	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(check)->child),
 															_("Enable _Case"));
 	gtk_widget_add_accelerator(check,"clicked",accel,key,GDK_MOD1_MASK,0);
@@ -141,10 +142,10 @@ gint replace_dialog(ReplaceString *rp)
 		gtk_editable_select_region(GTK_EDITABLE(GTK_COMBO(combo0)->entry),
 																		0,-1);
 	}
-	gtk_signal_connect(GTK_OBJECT(GTK_COMBO(combo0)->entry),"activate",
-												replace_dialog_activate,rp);
-	gtk_signal_connect(GTK_OBJECT(GTK_COMBO(combo0)->entry),"changed",
-												replace_dialog_changed,NULL);
+	g_signal_connect (G_OBJECT (GTK_COMBO (combo0)->entry), "activate",
+									G_CALLBACK (replace_dialog_activate), rp);
+	g_signal_connect (G_OBJECT (GTK_COMBO(combo0)->entry), "changed",
+									G_CALLBACK (replace_dialog_changed), NULL);
 	glist=NULL;
 	for (i=0;i<replace_num;i++)
 		glist=g_list_append(glist,replace_text[i]);
@@ -155,12 +156,12 @@ gint replace_dialog(ReplaceString *rp)
 		gtk_entry_set_text(GTK_ENTRY(GTK_COMBO(combo1)->entry),
 															replace_text[0]);
 	}
-	gtk_signal_connect(GTK_OBJECT(GTK_COMBO(combo1)->entry),"activate",
-												replace_dialog_activate,rp);
+	g_signal_connect (G_OBJECT (GTK_COMBO (combo1)->entry), "activate",
+									G_CALLBACK (replace_dialog_activate), rp);
 	/* 饸ܥ */
-	radio0=gtk_radio_button_new_with_label(NULL,NULL);
-	radio1=gtk_radio_button_new_with_label_from_widget(
-												GTK_RADIO_BUTTON(radio0),NULL);
+	radio0 = gtk_radio_button_new_with_label (NULL, "");
+	radio1 = gtk_radio_button_new_with_label_from_widget (
+												GTK_RADIO_BUTTON (radio0), "");
 	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(radio0)->child),_("_Up"));
 	gtk_widget_add_accelerator(radio0,"clicked",accel,key,GDK_MOD1_MASK,0);
 	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(radio1)->child),_("_Down"));
