@@ -20,7 +20,7 @@
 #include <unistd.h>
 #include "tmaid.h"
 #include "argument.h"
-#include "charset.h"
+#include "charlist.h"
 #include "command.h"
 #include "conf.h"
 #include "file.h"
@@ -28,11 +28,10 @@
 #include "format.h"
 #include "general.h"
 #include "jump.h"
-#ifdef USE_GDKPIXBUF
-# include "print.h"
-#endif
+#include "print.h"
 #include "replace.h"
-#include "signal.h"
+#include "sigfile.h"
+#include "sigmain.h"
 #include "toolbar.h"
 #include "version.h"
 #include "misc/misc.h"
@@ -58,8 +57,9 @@ guint timer_id=0;					/* ID */
 FileType *ftype=NULL;				/* ե륿 */
 GdkAtom atom_clipboard;				/* åץܡ */
 GdkAtom atom_targets;				/* å */
-GdkAtom atom_compound;				/* ѥ */
 GdkAtom atom_text;					/* ƥ */
+GdkAtom atom_compound;				/* ѥ */
+GdkAtom atom_utf8;					/* UTF-8 */
 GdkAtom atom_textmaid0;				/* ץ̿ѥȥ */
 GdkAtom atom_textmaid1;				/* ץ̿ѥȥ */
 GtkWidget *window;					/* ɥ */
@@ -69,17 +69,18 @@ GtkWidget *label_cursor;			/* ɸ */
 GtkPositionType n_pos=GTK_POS_TOP;	/* Ρȥ֥åΰ */
 GtkItemFactory *item_factory_menu;	/* ˥塼 */
 GtkItemFactory *item_factory_popup;	/* ݥåץå */
-GdkFont *system_font=NULL;
+PangoFontDescription *system_font = NULL;
 GdkColor system_color[12]={	{0,0x0000,0x0000,0x0000},{0,0xffff,0xffff,0xffff},
 							{0,0x8000,0x8000,0x8000},{0,0x8000,0x8000,0x8000},
 							{0,0x8000,0x8000,0x8000},{0,0x8000,0x8000,0x8000},
 							{0,0x8000,0x8000,0x8000},{0,0xa000,0xa000,0xa000},
 							{0,0xffff,0xffff,0xffff},{0,0x0000,0x0000,0x8000},
 							{0,0x0000,0x0000,0x0000},{0,0xffff,0xffff,0xffff}};
-GtkTargetEntry targets[3]={			/* Text maid󶡲ǽʥ쥯 */
+GtkTargetEntry targets[4]={			/* Text maid󶡲ǽʥ쥯 */
 	{"STRING",       0,TARGET_STRING},
 	{"TEXT",         0,TARGET_TEXT}, 
-	{"COMPOUND_TEXT",0,TARGET_COMPOUND_TEXT}};
+	{"COMPOUND_TEXT",0,TARGET_COMPOUND_TEXT},
+	{"UTF8_STRING",  0,TARGET_UTF8}};
 
 
 /******************************************************************************
@@ -96,8 +97,9 @@ static gchar *menu_translate(const gchar *path,gpointer func_data)
 int main(int argc,char *argv[])
 {
 	gboolean *arg_files;
-	gchar *arg,*section,*key;
-	gint i,count=0,leng,length=0;
+	gchar *arg, *section, *key, *tmp;
+	const gchar *charset;
+	gint i, count=0, leng, length=0;
 	Profile *profile;
 	TmaidWindow *tmaid;
 	GdkBitmap *mask;
@@ -105,7 +107,7 @@ int main(int argc,char *argv[])
 	GtkAccelGroup *accel_group;
 	GtkStyle *style;
 	GtkWidget *menu_bar, *menu_shell, *menu_item;
-	GtkWidget *handle,*text,*table,*toolbar,*vbox,*frame;
+	GtkWidget *handle, *label, *table, *toolbar, *vbox, *frame;
 	GtkItemFactoryEntry menu_items[]={
 {N_("/_File"),                       NULL,         NULL,            0,"<Branch>"},
 {N_("/File/_New"),                   "<control>N", command_new,     0,"<Item>"},
@@ -115,10 +117,8 @@ int main(int argc,char *argv[])
 {N_("/File/Save _As..."),            NULL,         command_saveas,  0,"<Item>"},
 {N_("/File/_Reload"),                "<control>R", command_reload,  0,"<Item>"},
 {N_("/File/Sep1"),                   NULL,         NULL,            0,"<Separator>"},
-#ifdef USE_GDKPIXBUF
 {N_("/File/_Print..."),              "<control>P", command_print,   0,"<Item>"},
 {N_("/File/Sep2"),                   NULL,         NULL,            0,"<Separator>"},
-#endif
 {N_("/File/Propert_ies..."),         "<alt>Return",command_property,0,"<Item>"},
 {N_("/File/Sep3"),                   NULL,         NULL,            0,"<Separator>"},
 {N_("/File/E_xit"),                  "<control>Q", command_exit,    0,"<Item>"},
@@ -157,17 +157,19 @@ int main(int argc,char *argv[])
 {N_("/_Paste"),                      "<control>V", command_paste,   0,"<Item>"},
 {N_("/De_lete"),                     NULL,         command_delete,  0,"<Item>"},
 {"/Sep2",                            NULL,         NULL,            0,"<Separator>"},
-{N_("/_All"),                        "<control>A", command_all,     0,"<Item>"}};
+{N_("/_All"),                        "<control>A", command_all,     0,"<Item>"},
+{"/Sep3",                            NULL,         NULL,            0,"<Separator>"},
+{N_("/_Input Methods"),              NULL,         NULL,            0,"<Item>"}};
 	/* Drag&Drop */
 	GtkTargetEntry drag_types[1]={{"text/uri-list",0,0}};
 
 	/*  */
 	setlocale(LC_ALL,"");
 	bindtextdomain(PACKAGE,LOCALEDIR);
+	bind_textdomain_codeset(PACKAGE,"UTF-8");
 	textdomain(PACKAGE);
 	gtk_set_locale();
 	gtk_init(&argc,&argv);
-	charset_init();
 
 	def_width=gdk_screen_width()*2/3;
 	def_height=gdk_screen_height()*2/3;
@@ -250,7 +252,6 @@ int main(int argc,char *argv[])
 				break;
 		}
 		replace_num=i;
-#ifdef USE_GDKPIXBUF
 		/*  */
 		if (!profile_get_value(profile,"printer","mode",
 								(gpointer)&printer.mode,sizeof(gboolean),
@@ -285,7 +286,6 @@ int main(int argc,char *argv[])
 										(gpointer)&printer.bottom,sizeof(gint),
 													PROFILE_VALUE_TYPE_INT))
 			printer.bottom=20;
-#endif
 		/* ե륿 */
 		if (ftnum>0)
 			ftype=g_malloc(ftnum*sizeof(FileType));
@@ -297,6 +297,10 @@ int main(int argc,char *argv[])
 				ftype[i].text=g_strdup("UNKNOW");
 			if ((ftype[i].ext=profile_get_string(profile,section,"ext"))==NULL)
 				ftype[i].ext=g_strdup("*");
+			if (!profile_get_value (profile, section, "crlf",
+									(gpointer)&ftype[i].crlf, sizeof (gint),
+													PROFILE_VALUE_TYPE_INT))
+				ftype[i].crlf = 3;
 			if (!profile_get_value(profile,section,"margin",
 									(gpointer)&ftype[i].margin,sizeof(gint),
 													PROFILE_VALUE_TYPE_INT))
@@ -305,6 +309,10 @@ int main(int argc,char *argv[])
 										(gpointer)&ftype[i].tab,sizeof(gint),
 													PROFILE_VALUE_TYPE_INT))
 				ftype[i].tab=8;
+			if (!profile_get_value (profile, section, "writemode",
+								(gpointer)&ftype[i].writemode, sizeof (gint),
+													PROFILE_VALUE_TYPE_INT))
+				ftype[i].writemode = 0;
 			if (!profile_get_value(profile,section,"associate",
 								(gpointer)&ftype[i].associate,sizeof(gboolean),
 													PROFILE_VALUE_TYPE_BOOL))
@@ -321,6 +329,18 @@ int main(int argc,char *argv[])
 									(gpointer)&ftype[i].eof,sizeof(gboolean),
 													PROFILE_VALUE_TYPE_BOOL))
 				ftype[i].eof=FALSE;
+			if (!profile_get_value (profile, section, "hexcase",
+								(gpointer)&ftype[i].hexcase, sizeof (gboolean),
+													PROFILE_VALUE_TYPE_BOOL))
+				ftype[i].hexcase = FALSE;
+			if (!profile_get_value (profile, section, "html",
+								(gpointer)&ftype[i].html, sizeof (gboolean),
+													PROFILE_VALUE_TYPE_BOOL))
+				ftype[i].html = FALSE;
+			if (!profile_get_value (profile, section, "esc",
+									(gpointer)&ftype[i].esc, sizeof (gboolean),
+													PROFILE_VALUE_TYPE_BOOL))
+				ftype[i].esc = FALSE;
 			if (!profile_get_value(profile,section,"limit",
 									(gpointer)&ftype[i].limit,sizeof(gboolean),
 													PROFILE_VALUE_TYPE_BOOL))
@@ -357,6 +377,19 @@ int main(int argc,char *argv[])
 									(gpointer)&ftype[i].vline,sizeof(gboolean),
 													PROFILE_VALUE_TYPE_BOOL))
 				ftype[i].vline=FALSE;
+			/* 饯å */
+			ftype[i].charset = profile_get_string
+												(profile, section, "charset");
+			if (ftype[i].charset != NULL)
+			  {
+				tmp = charlist_strip (ftype[i].charset);
+				g_free (ftype[i].charset);
+				ftype[i].charset = tmp;
+			  }
+			if (ftype[i].charset == NULL)
+				ftype[i].charset = g_get_charset (&charset)
+										? g_strdup_printf ("%s,UTF-8", charset)
+														: g_strdup ("UTF-8");
 			/* ե */
 			if ((ftype[i].font_name
 							=profile_get_string(profile,section,"font"))==NULL)
@@ -369,7 +402,6 @@ int main(int argc,char *argv[])
 			g_free(section);
 		}
 		profile_close(profile);
-#ifdef USE_GDKPIXBUF
 	} else {
 		printer.mode=TRUE;
 		printer.printer=g_strdup("lpr");
@@ -377,7 +409,6 @@ int main(int argc,char *argv[])
 		printer.width=594;
 		printer.height=840;
 		printer.left=printer.top=printer.right=printer.bottom=20;
-#endif
 	}
 
 	/* ޥɥ饤β */
@@ -389,10 +420,14 @@ int main(int argc,char *argv[])
 		ftype = g_malloc0 (ftnum * sizeof (FileType));
 		ftype[0].text=g_strdup(_("All Files"));
 		ftype[0].ext=g_strdup("*");
+		ftype[0].crlf = 3;
 		ftype[0].margin=80;
 		ftype[0].tab=8;
 		ftype[0].associate=TRUE;
 		ftype[0].syscol=TRUE;
+		/* 饯å */
+		ftype[0].charset = g_get_charset (&charset)
+				? g_strdup_printf ("%s,UTF-8", charset) : g_strdup ("UTF-8");
 		/*  */
 		g_memmove(ftype[0].color,system_color,sizeof(GdkColor)*12);
 	}
@@ -401,22 +436,23 @@ int main(int argc,char *argv[])
 	window=gtk_window_new(GTK_WINDOW_TOPLEVEL);
 	gtk_window_set_title(GTK_WINDOW(window),"Text maid");
 	gtk_window_set_default_size(GTK_WINDOW(window),def_width,def_height);
-	gtk_signal_connect(GTK_OBJECT(window),"delete-event",
-										GTK_SIGNAL_FUNC(signal_delete),NULL);
-	gtk_signal_connect(GTK_OBJECT(window),"destroy",
-												signal_destroy_window,NULL);
+	g_signal_connect (G_OBJECT(window), "delete-event",
+											G_CALLBACK (signal_delete), NULL);
+	g_signal_connect (G_OBJECT (window), "destroy",
+									G_CALLBACK (signal_destroy_window), NULL);
 	gtk_widget_realize(window);
 	/* Drag and Drop */
 	gtk_drag_dest_set(window,GTK_DEST_DEFAULT_MOTION
 						| GTK_DEST_DEFAULT_HIGHLIGHT | GTK_DEST_DEFAULT_DROP,
 												drag_types,1,GDK_ACTION_COPY);
-	gtk_signal_connect(GTK_OBJECT(window),"drag-data-received",
-							GTK_SIGNAL_FUNC(signal_drag_data_received),NULL);
+	g_signal_connect (G_OBJECT (window), "drag-data-received",
+								G_CALLBACK (signal_drag_data_received), NULL);
 	/* åץܡ/ץ̿ */
 	atom_clipboard=gdk_atom_intern("CLIPBOARD",FALSE);
 	atom_targets=gdk_atom_intern("TARGETS",FALSE);
 	atom_compound=gdk_atom_intern("COMPOUND_TEXT",FALSE);
 	atom_text=gdk_atom_intern("TEXT",FALSE);
+	atom_utf8 = gdk_atom_intern ("UTF8_STRING", FALSE);
 	atom_textmaid0=gdk_atom_intern("Text maid InterProcess communication 0",
 																		FALSE);
 	atom_textmaid1=gdk_atom_intern("Text maid InterProcess communication 1",
@@ -427,20 +463,20 @@ int main(int argc,char *argv[])
 		gtk_selection_add_targets(window,atom_textmaid0,targets,1);
 		gtk_selection_add_targets(window,atom_textmaid1,targets,1);
 	}
-	gtk_signal_connect(GTK_OBJECT(window),"selection-clear-event",
-								GTK_SIGNAL_FUNC(signal_selection_clear),NULL);
-	gtk_signal_connect(GTK_OBJECT(window),"selection-get",
-											signal_selection_get,NULL);
-	gtk_signal_connect(GTK_OBJECT(window),"selection-received",
-											signal_selection_received,NULL);
+	g_signal_connect (G_OBJECT (window), "selection-clear-event",
+									G_CALLBACK (signal_selection_clear), NULL);
+	g_signal_connect (G_OBJECT (window), "selection-get",
+									G_CALLBACK (signal_selection_get), NULL);
+	g_signal_connect (GTK_OBJECT (window), "selection-received",
+								G_CALLBACK (signal_selection_received), NULL);
 	/* Ρȥ֥å */
 	notebook=gtk_notebook_new();
 	gtk_notebook_set_scrollable(GTK_NOTEBOOK(notebook),TRUE);
 	gtk_notebook_set_tab_pos(GTK_NOTEBOOK(notebook),n_pos);
-	gtk_signal_connect(GTK_OBJECT(notebook),"switch-page",
-								GTK_SIGNAL_FUNC(signal_switch_page),NULL);
-	gtk_signal_connect(GTK_OBJECT(notebook),"destroy",
-								GTK_SIGNAL_FUNC(signal_destroy_notebook),NULL);
+	g_signal_connect (G_OBJECT (notebook), "switch-page",
+										G_CALLBACK (signal_switch_page),NULL);
+	g_signal_connect (G_OBJECT (notebook), "destroy",
+									G_CALLBACK (signal_destroy_notebook),NULL);
 	/* ݥåץå */
 	accel_group=gtk_accel_group_new();
 	item_factory_popup=gtk_item_factory_new(GTK_TYPE_MENU,
@@ -457,10 +493,13 @@ int main(int argc,char *argv[])
 																	NULL,NULL);
 	gtk_item_factory_create_items(item_factory_menu,
 			sizeof(menu_items)/sizeof(GtkItemFactoryEntry),menu_items,NULL);
-	gtk_accel_group_attach(accel_group,GTK_OBJECT(window));
+	gtk_window_add_accel_group (GTK_WINDOW (window), accel_group);
 	menu_bar = gtk_item_factory_get_widget (item_factory_menu, "<main>");
 	/* ġС */
-	toolbar=gtk_toolbar_new(GTK_ORIENTATION_HORIZONTAL,GTK_TOOLBAR_ICONS);
+	toolbar = gtk_toolbar_new ();
+	gtk_toolbar_set_orientation (GTK_TOOLBAR (toolbar),
+												GTK_ORIENTATION_HORIZONTAL);
+	gtk_toolbar_set_style (GTK_TOOLBAR (toolbar), GTK_TOOLBAR_ICONS);
 	for (i=0;toolbar_items[i].name!=(gpointer)-1;i++)
 		if (toolbar_items[i].name==NULL) {
 			gtk_toolbar_append_space(GTK_TOOLBAR(toolbar));
@@ -482,8 +521,9 @@ int main(int argc,char *argv[])
 	frame = gtk_frame_new(NULL);
 	gtk_container_add( GTK_CONTAINER (frame), label_cursor);
 	/* ƥ */
-	text=gtk_text_new(NULL,NULL);
-	gtk_signal_connect(GTK_OBJECT(text),"style-set",signal_style_set,NULL);
+	label = gtk_label_new ("");
+	g_signal_connect (G_OBJECT (label), "style-set",
+										G_CALLBACK (signal_style_set), NULL);
 	/* ľܥå/ϥɥܥå */
 	vbox=gtk_vbox_new(FALSE,0);
 	handle=gtk_handle_box_new();
@@ -500,18 +540,19 @@ int main(int argc,char *argv[])
 	gtk_table_attach (GTK_TABLE (table), frame, 4, 5, 0, 1,
 			GTK_EXPAND | GTK_SHRINK | GTK_FILL, GTK_SHRINK | GTK_FILL, 0, 0);
 	gtk_box_pack_end(GTK_BOX(vbox),table,FALSE,FALSE,0);
-	gtk_box_pack_end(GTK_BOX(vbox),text,FALSE,FALSE,0);
+	gtk_box_pack_end (GTK_BOX (vbox), label, FALSE, FALSE, 0);
 	gtk_container_add(GTK_CONTAINER(window),vbox);
 	/* ե */
 	menu_shell = gtk_item_factory_get_widget (item_factory_menu,
 																"<main>/File");
 	for (i=0;i<history && history_files[i]!=NULL;i++) {
 		menu_item=gtk_menu_item_new_with_label(history_files[i]);
-		gtk_signal_connect(GTK_OBJECT(menu_item),"activate",
-			GTK_SIGNAL_FUNC(signal_activate_menu_history),history_files[i]);
-		gtk_signal_connect(GTK_OBJECT(menu_item),"destroy",
-			GTK_SIGNAL_FUNC(signal_destroy_menu_history),history_files[i]);
-		gtk_object_set_user_data(GTK_OBJECT(menu_item),history_files[i]);
+		g_signal_connect (G_OBJECT (menu_item), "activate",
+				G_CALLBACK (signal_activate_menu_history), history_files[i]);
+		g_signal_connect (G_OBJECT (menu_item), "destroy",
+				G_CALLBACK (signal_destroy_menu_history), history_files[i]);
+		g_object_set_data (G_OBJECT (menu_item), "user_data",
+															history_files[i]);
 		gtk_menu_insert (GTK_MENU (menu_shell), menu_item, i + MENUFILE - 1);
 	}
 	if (i>0)
@@ -570,11 +611,11 @@ int main(int argc,char *argv[])
 
 	/* ɽ */
 	gtk_widget_show_all(window);
-	gtk_widget_hide_all(text);
+	gtk_widget_hide_all (label);
 	gtk_window_set_policy(GTK_WINDOW(window),TRUE,TRUE,TRUE);
 
 	/* ƥ࿧ */
-	style=gtk_widget_get_style(text);
+	style=gtk_widget_get_style (label);
 	system_color[0]=style->text[0];
 	system_color[1]=style->base[0];
 	system_color[2]=style->dark[0];
@@ -586,7 +627,9 @@ int main(int argc,char *argv[])
 	system_color[8]=style->fg[3];
 	system_color[9]=style->bg[3];
 	/* ƥե */
-	system_font=gdk_font_ref(style->font);
+	system_font = pango_font_description_copy
+									(pango_context_get_font_description
+									(gtk_widget_get_pango_context (label)));
 
 	/* ɥ */
 	for (i=1;i<argc;i++)
@@ -684,7 +727,6 @@ int main(int argc,char *argv[])
 													PROFILE_VALUE_TYPE_STRING);
 			g_free(key);
 		}
-#ifdef USE_GDKPIXBUF
 		/*  */
 		profile_set_value(profile,"printer","mode",
 									(gpointer)&printer.mode,sizeof(gboolean),
@@ -714,7 +756,6 @@ int main(int argc,char *argv[])
 		profile_set_value(profile,"printer","bottom",
 										(gpointer)&printer.bottom,sizeof(gint),
 													PROFILE_VALUE_TYPE_INT);
-#endif
 		/* ե륿 */
 		section=NULL;
 		for (i=0;i<ftnum;i++) {
@@ -725,12 +766,18 @@ int main(int argc,char *argv[])
 			profile_set_value(profile,section,"ext",(gpointer)ftype[i].ext,
 									(g_strlen(ftype[i].ext)+1)*sizeof(gchar),
 													PROFILE_VALUE_TYPE_STRING);
+			profile_set_value (profile, section, "crlf",
+									(gpointer)&ftype[i].crlf, sizeof (gint),
+													PROFILE_VALUE_TYPE_INT);
 			profile_set_value(profile,section,"margin",
 									(gpointer)&ftype[i].margin,sizeof(gint),
 													PROFILE_VALUE_TYPE_INT);
 			profile_set_value(profile,section,"tab",
 										(gpointer)&ftype[i].tab,sizeof(gint),
 													PROFILE_VALUE_TYPE_INT);
+			profile_set_value (profile,section, "writemode",
+								(gpointer)&ftype[i].writemode, sizeof (gint),
+													PROFILE_VALUE_TYPE_INT);
 			profile_set_value(profile,section,"associate",
 								(gpointer)&ftype[i].associate,sizeof(gboolean),
 													PROFILE_VALUE_TYPE_BOOL);
@@ -743,6 +790,15 @@ int main(int argc,char *argv[])
 			profile_set_value(profile,section,"eof",
 									(gpointer)&ftype[i].eof,sizeof(gboolean),
 													PROFILE_VALUE_TYPE_BOOL);
+			profile_set_value (profile, section, "hexcase",
+								(gpointer)&ftype[i].hexcase, sizeof (gboolean),
+													PROFILE_VALUE_TYPE_BOOL);
+			profile_set_value (profile, section, "html",
+								(gpointer)&ftype[i].html, sizeof (gboolean),
+													PROFILE_VALUE_TYPE_BOOL);
+			profile_set_value (profile, section, "esc",
+									(gpointer)&ftype[i].esc, sizeof (gboolean),
+													PROFILE_VALUE_TYPE_BOOL);
 			profile_set_value(profile,section,"limit",
 									(gpointer)&ftype[i].limit,sizeof(gboolean),
 													PROFILE_VALUE_TYPE_BOOL);
@@ -770,6 +826,11 @@ int main(int argc,char *argv[])
 			profile_set_value(profile,section,"vline",
 									(gpointer)&ftype[i].vline,sizeof(gboolean),
 													PROFILE_VALUE_TYPE_BOOL);
+			/* 饯å */
+			profile_set_value (profile, section, "charset",
+							(gpointer)ftype[i].charset,
+							(g_strlen (ftype[i].charset) + 1) * sizeof (gchar),
+													PROFILE_VALUE_TYPE_STRING);
 			/* ե */
 			if (ftype[i].font_name!=NULL)
 				profile_set_value(profile,section,"font",
@@ -788,14 +849,12 @@ int main(int argc,char *argv[])
 		g_free(section);
 		profile_close(profile);
 	}
-	gdk_font_unref(system_font);
+	pango_font_description_free (system_font);
 	g_free(open_path);
 	g_free(save_path);
 	g_free(clipboard_text);
-#ifdef USE_GDKPIXBUF
 	g_free(printer.printer);
 	g_free(printer.file);
-#endif
 	for (i=0;i<find_num;i++)
 		g_free(find_text[i]);
 	for (i=0;i<replace_num;i++)
