@@ -26,21 +26,22 @@
 #define TMAID_VERSION_NOTICE "Text maid "VERSION" ("TMAID_BUILD_ENVIRONMENT")"
 #define TMAID_COPYRIGHT_NOTICE "Copyright (C) 1998-2003 Kazuki IWAMOTO"
 
-#ifdef USE_GDKPIXBUF
 #define MENUFILE 12
-#else
-#define MENUFILE 10
-#endif
 
 
 typedef struct FileType_Tag {
-	gint ft_id;					/* ե륿פID */
+	gint ft_id;					/* ե륿פID(-1:̵°) */
+	gint crlf;					/* 0:CR+LF,1:CR,2:LF,3:ư */
 	gint margin;				/* ޡο */
 	gint tab;					/* ֤ο */
+	gint writemode;				/* 0:Abort,1:'?',2:HTML,3:Escape */
 	gboolean autoindent;		/* TRUE:ư */
 	gboolean associate;			/* TRUE:ϢŤ */
 	gboolean code;				/* TRUE:֤Υɤɽ */
 	gboolean eof;				/* TRUE:1Ahե˽񤭲ä */
+	gboolean hexcase;			/* TRUE:ʸ,FALSE:ʸ */
+	gboolean html;				/* TRUE:HTMLʸȤѴ */
+	gboolean esc;				/* TRUE:ץ󥹤Ѵ */
 	gboolean limit;				/* TRUE:ޡޤ֤ */
 	gboolean overwrite;			/* TRUE:ե񤭤Ȥ˳ǧ */
 	gboolean space;				/* TRUE:ڡ򳥿λͳѤɽ */
@@ -50,6 +51,7 @@ typedef struct FileType_Tag {
 	gboolean nline;				/* TRUE:ԥɤɽ */
 	gboolean uline;				/* TRUE:ֲɽ */
 	gboolean vline;				/* TRUE:ֽɽ */
+	gchar *charset;				/* 饯å */
 	gchar *font_name;			/* ե̾ */
 	gchar *text,*ext;			/* ̾,ĥ */
 	GdkColor color[12];			/*  */
@@ -73,19 +75,15 @@ typedef struct TmaidWindow_Tag {
 	gchar *file;				/* ե̾ */
 	gint font_width;			/* եȤβ */
 	gint font_height;			/* եȤι⤵ */
-	gint font_ascent;			/* եȤΥȤι⤵ */
 	gint max;					/* Կ */
 	gint off;					/* startȤ */
 	gint same;					/* -1:ʣʤ,0:ֹ */
 	guint timer_id;				/* ѥ */
+	guint8 font_buf[65536];		/* ʸΥХåե */
 	FileType ft;				/* ե륿 */
 	LineBuffer *start;			/* ꥹ */
+	PangoLayout *layout;		/* 쥤 */
 	TmaidHistory *undo,*redo;	/* Խ */
-	GdkFont *font;				/* ե */
-#ifdef USE_XIM
-	GdkIC *ic;					/* XIM */
-	GdkICAttr *ic_attr;			/* XIM° */
-#endif /* USE_XIM */
 	GdkPoint top;				/* ɥƬ */
 	GdkPoint cursor;			/* åȤΰ */
 	GdkPoint select;			/* 򳫻ϰ,-1:ʤ */
@@ -95,13 +93,16 @@ typedef struct TmaidWindow_Tag {
 	GtkWidget *label;			/* ֤Υ٥ */
 	GtkWidget *mark;			/* ֤ԽѤߥޡ */
 	GtkWidget *menu_item;		/* ˥塼Υɥι */
+	GtkIMContext *im_context;	/* Input Method */
+	GtkWidget *preedit;			/* ΰ(̤ʸ) */
 } TmaidWindow;
 
 
 enum {
 	TARGET_STRING,
 	TARGET_TEXT,
-	TARGET_COMPOUND_TEXT
+	TARGET_COMPOUND_TEXT,
+	TARGET_UTF8
 };
 
 
@@ -124,8 +125,9 @@ extern guint timer_id;					/* ID */
 extern FileType *ftype;					/* ե륿 */
 extern GdkAtom atom_clipboard;			/* åץܡ */
 extern GdkAtom atom_targets;			/* å */
-extern GdkAtom atom_compound;			/* ѥ */
 extern GdkAtom atom_text;				/* ƥ */
+extern GdkAtom atom_compound;			/* ѥ */
+extern GdkAtom atom_utf8;				/* UTF-8 */
 extern GdkAtom atom_textmaid0;			/* ץ̿ѥȥ */
 extern GdkAtom atom_textmaid1;			/* ץ̿ѥȥ */
 extern GtkWidget *window;				/* ɥ */
@@ -135,9 +137,9 @@ extern GtkWidget *label_cursor;			/* ɸ */
 extern GtkPositionType n_pos;			/* Ρȥ֥åΰ */
 extern GtkItemFactory *item_factory_menu;	/* ˥塼 */
 extern GtkItemFactory *item_factory_popup;	/* ݥåץå */
-extern GdkFont *system_font;
+extern PangoFontDescription *system_font;
 extern GdkColor system_color[12];
-extern GtkTargetEntry targets[3];		/* Text maid󶡲ǽʥ쥯 */
+extern GtkTargetEntry targets[4];		/* Text maid󶡲ǽʥ쥯 */
 
 
 #endif
