@@ -126,7 +126,6 @@ static gchar *tb_prop_xpm[]={
 "                "};
 
 
-#ifdef USE_GDKPIXBUF
 static gchar *tb_print_xpm[]={
 "16 16 7 1",
 " 	c None",
@@ -152,7 +151,6 @@ static gchar *tb_print_xpm[]={
 ".###########.#. ",
 ".###########..  ",
 " ...........    "};
-#endif
 
 
 /* XPM */
@@ -360,10 +358,8 @@ ToolBar toolbar_items[]={
 /*  3 */ {NULL,            NULL,          NULL,            NULL,NULL},
 /*  4 */ {N_("Properties"),tb_prop_xpm,   command_property,NULL,NULL},
 /*  5 */ {NULL,            NULL,          NULL,            NULL,NULL},
-#ifdef USE_GDKPIXBUF
 /*  6 */ {N_("Print"),     tb_print_xpm,  command_print,   NULL,NULL},
 /*  7 */ {NULL,            NULL,          NULL,            NULL,NULL},
-#endif
 /*  8 */ {N_("Cut"),       tb_cut_xpm,    command_cut,     NULL,NULL},
 /*  9 */ {N_("Copy"),      tb_copy_xpm,   command_copy,    NULL,NULL},
 /* 10 */ {N_("Paste"),     tb_paste_xpm,  command_paste,   NULL,NULL},
