@@ -103,21 +103,22 @@ gboolean valchr_dialog(gchar *valchr)
 	GtkWidget *button1,*radio0,*radio1,*radio2,*frame,*hbox,*vbox;
 
 	/* ᥤ󥦥ɥ */
-	dialog=gtk_window_new(GTK_WINDOW_DIALOG);
+	dialog = gtk_window_new (GTK_WINDOW_TOPLEVEL);
 	gtk_window_set_title(GTK_WINDOW(dialog),_("Character by Value"));
-	gtk_signal_connect_after(GTK_OBJECT(dialog),"key-press-event",
-								GTK_SIGNAL_FUNC(valchr_dialog_key_press),NULL);
-	gtk_signal_connect(GTK_OBJECT(dialog),"destroy",gtk_main_quit,NULL);
+	g_signal_connect_after (G_OBJECT (dialog), "key-press-event",
+								G_CALLBACK (valchr_dialog_key_press), NULL);
+	g_signal_connect (G_OBJECT (dialog), "destroy",
+											G_CALLBACK (gtk_main_quit), NULL);
 	/* 졼 */
 	accel=gtk_accel_group_new();
-	gtk_accel_group_attach(accel,GTK_OBJECT(dialog));
+	gtk_window_add_accel_group (GTK_WINDOW (dialog), accel);
 	/* ܥ */
 	button0=gtk_button_new_with_label(_("OK"));
 	button1=gtk_button_new_with_label(_("Cancel"));
-	gtk_signal_connect(GTK_OBJECT(button0),"clicked",
-										valchr_dialog_clicked_ok,valchr);
-	gtk_signal_connect_object(GTK_OBJECT(button1),"clicked",
-										gtk_widget_destroy,GTK_OBJECT(dialog));
+	g_signal_connect (G_OBJECT (button0), "clicked",
+								G_CALLBACK (valchr_dialog_clicked_ok), valchr);
+	g_signal_connect_swapped (G_OBJECT (button1), "clicked",
+						G_CALLBACK (gtk_widget_destroy), G_OBJECT (dialog));
 	GTK_WIDGET_SET_FLAGS(button0,GTK_CAN_DEFAULT);
 	GTK_WIDGET_SET_FLAGS(button1,GTK_CAN_DEFAULT);
 	/* ȥ꡼ */
@@ -125,15 +126,16 @@ gboolean valchr_dialog(gchar *valchr)
 	text=misc_str_from_val(valchr_default,valchr_base,0,FALSE);
 	gtk_entry_set_text(GTK_ENTRY(entry),text);
 	g_free(text);
-	gtk_signal_connect(GTK_OBJECT(entry),"activate",
-												valchr_dialog_activate,valchr);
-	gtk_signal_connect(GTK_OBJECT(entry),"changed",valchr_dialog_changed,NULL);
+	g_signal_connect (G_OBJECT (entry), "activate",
+								G_CALLBACK (valchr_dialog_activate), valchr);
+	g_signal_connect (G_OBJECT (entry), "changed",
+									G_CALLBACK (valchr_dialog_changed), NULL);
 	/* 饸ܥ */
-	radio0=gtk_radio_button_new_with_label(NULL,NULL);
-	radio1=gtk_radio_button_new_with_label_from_widget(
-												GTK_RADIO_BUTTON(radio0),NULL);
-	radio2=gtk_radio_button_new_with_label_from_widget(
-												GTK_RADIO_BUTTON(radio1),NULL);
+	radio0 = gtk_radio_button_new_with_label (NULL, "");
+	radio1 = gtk_radio_button_new_with_label_from_widget (
+												GTK_RADIO_BUTTON (radio0), "");
+	radio2 = gtk_radio_button_new_with_label_from_widget (
+												GTK_RADIO_BUTTON (radio1), "");
 	key=gtk_label_parse_uline(GTK_LABEL(GTK_BIN(radio0)->child),
 															_("_Hexadecimal"));
 	gtk_widget_add_accelerator(radio0,"clicked",accel,key,GDK_MOD1_MASK,0);
@@ -146,12 +148,12 @@ gboolean valchr_dialog(gchar *valchr)
 	case 10:gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(radio1),TRUE);break;
 	case  8:gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(radio2),TRUE);
 	}
-	gtk_signal_connect(GTK_OBJECT(radio0),"clicked",
-									valchr_dialog_clicked_radio,(gpointer)16);
-	gtk_signal_connect(GTK_OBJECT(radio1),"clicked",
-									valchr_dialog_clicked_radio,(gpointer)10);
-	gtk_signal_connect(GTK_OBJECT(radio2),"clicked",
-									valchr_dialog_clicked_radio,(gpointer)8);
+	g_signal_connect (G_OBJECT (radio0), "clicked",
+					G_CALLBACK (valchr_dialog_clicked_radio), (gpointer)16);
+	g_signal_connect (G_OBJECT (radio1), "clicked",
+					G_CALLBACK (valchr_dialog_clicked_radio), (gpointer)10);
+	g_signal_connect (G_OBJECT (radio2), "clicked",
+					G_CALLBACK (valchr_dialog_clicked_radio), (gpointer)8);
 	/* ե졼ȥܥå */
 	frame=gtk_frame_new(_("Base"));
 	vbox=gtk_vbox_new(FALSE,8);
