@@ -1,6 +1,6 @@
 /*
     Text maid
-    copyright (c) 1998-2002 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2003 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -87,15 +87,16 @@ static gchar *tmaid_xpm[] = {
 "  +$$$$$+$$$$$$$$$$$$$+$$$$$+   "};
 
 	/* ᥤ󥦥ɥ */
-	dialog=gtk_window_new(GTK_WINDOW_DIALOG);
+	dialog = gtk_window_new (GTK_WINDOW_TOPLEVEL);
 	gtk_window_set_title(GTK_WINDOW(dialog),_("About Text maid"));
-	gtk_signal_connect(GTK_OBJECT(dialog),"key-press-event",
-							GTK_SIGNAL_FUNC(version_dialog_key_press),NULL);
-	gtk_signal_connect(GTK_OBJECT(dialog),"destroy",gtk_main_quit,NULL);
+	g_signal_connect (G_OBJECT (dialog), "key-press-event",
+								G_CALLBACK (version_dialog_key_press), NULL);
+	g_signal_connect (G_OBJECT (dialog), "destroy",
+											G_CALLBACK (gtk_main_quit), NULL);
 	/* ܥ */
 	button=gtk_button_new_with_label(_("OK"));
-	gtk_signal_connect_object(GTK_OBJECT(button),"clicked",
-										gtk_widget_destroy,GTK_OBJECT(dialog));
+	g_signal_connect_swapped (G_OBJECT (button), "clicked",
+						G_CALLBACK (gtk_widget_destroy), G_OBJECT (dialog));
 	GTK_WIDGET_SET_FLAGS(button,GTK_CAN_DEFAULT);
 	/* ԥޥå */
 	pixmap=gdk_pixmap_create_from_xpm_d(window->window,&mask,NULL,tmaid_xpm);
@@ -104,8 +105,8 @@ static gchar *tmaid_xpm[] = {
 	vbox=gtk_vbox_new(FALSE,8);
 	gtk_container_set_border_width(GTK_CONTAINER(vbox),8);
 	hbox=gtk_hbox_new(FALSE,8);
-	gtk_box_pack_start(GTK_BOX(hbox),
-									gtk_pixmap_new(pixmap,mask),FALSE,FALSE,0);
+	gtk_box_pack_start (GTK_BOX (hbox),
+					gtk_image_new_from_pixmap (pixmap, mask), FALSE, FALSE, 0);
 	gtk_box_pack_start(GTK_BOX(hbox),gtk_label_new(TMAID_VERSION_NOTICE"\n"
                      TMAID_COPYRIGHT_NOTICE),TRUE,TRUE,0);
 	gtk_box_pack_start(GTK_BOX(vbox),hbox,FALSE,FALSE,0);
